@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2005 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -18,22 +18,17 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
  *  USA.
  *
- *  $Id: initLMS.php,v 1.3.2.1 2004/09/18 19:14:46 alec Exp $
+ *  $Id: initLMS.php,v 1.9.2.1 2005/05/13 20:09:47 alec Exp $
  */
 
-/*
- * To jest przykadowy plik do inicjacji klasy LMS'a do wykorzystania we
- * wasnych projektach PHP korzystajcych z LMS'a.
- */
-
-// cieka do pliku konfiguracyjnego
+// REPLACE THIS WITH PATH TO YOU CONFIG FILE
 
 $CONFIG_FILE = (is_readable('lms.ini')) ? 'lms.ini' : '/etc/lms/lms.ini';
 
-// Funkcja parsujca plik konfiguracyjny
+// Parse configuration file
 
 function lms_parse_ini_file($filename, $process_sections = false) 
 {
@@ -80,68 +75,49 @@ function lms_parse_ini_file($filename, $process_sections = false)
 	return $ini_array;
 }
 
-// Funkcja do sprawdzania wartoci logicznych z configa.
-
-function chkconfig($value, $default = FALSE)
-{
-        if(eregi('^(1|y|on|yes|true|tak|t)$', $value))
-                return TRUE;
-        elseif(eregi('^(0|n|no|off|false|nie)$', $value))
-                return FALSE;
-        elseif(!isset($value) || $value == '')
-                return $default;
-        else
-                trigger_error('Bdna warto opcji "'.$value.'"');
-}
-
-// Odczytanie pliku konfiguracyjnego
-
 foreach(lms_parse_ini_file($CONFIG_FILE, true) as $key => $val)
 	$_CONFIG[$key] = $val;
 
-// Domylne wartoci zmiennych ktrych nie da si gdzie indziej zdefiniowa.
-
+// Check for configuration vars and set default values
 $_CONFIG['directories']['sys_dir'] = (! $_CONFIG['directories']['sys_dir'] ? getcwd() : $_CONFIG['directories']['sys_dir']);
-$_CONFIG['directories']['backup_dir'] = (! $_CONFIG['directories']['backup_dir'] ? $_CONFIG['directories']['sys_dir'].'/backups' : $_CONFIG['directories']['backup_dir']);
 $_CONFIG['directories']['lib_dir'] = (! $_CONFIG['directories']['lib_dir'] ? $_CONFIG['directories']['sys_dir'].'/lib' : $_CONFIG['directories']['lib_dir']);
-$_CONFIG['directories']['modules_dir'] = (! $_CONFIG['directories']['modules_dir'] ? $_CONFIG['directories']['sys_dir'].'/modules' : $_CONFIG['directories']['modules_dir']);
-$_CONFIG['directories']['config_templates_dir'] = (! $_CONFIG['directories']['config_templates_dir'] ? $_CONFIG['directories']['sys_dir'].'/config_templates' : $_CONFIG['directories']['config_templates_dir']);
-$_CONFIG['directories']['smarty_dir'] = (! $_CONFIG['directories']['smarty_dir'] ? (is_readable('/usr/share/php/smarty/libs/Smarty.class.php') ? '/usr/share/php/smarty/libs' : $_CONFIG['directories']['lib_dir'].'/Smarty') : $_CONFIG['directories']['smarty_dir']);
-$_CONFIG['directories']['smarty_compile_dir'] = (! $_CONFIG['directories']['smarty_compile_dir'] ? $_CONFIG['directories']['sys_dir'].'/templates_c' : $_CONFIG['directories']['smarty_compile_dir']);
-$_CONFIG['directories']['smarty_templates_dir'] = (! $_CONFIG['directories']['smarty_templates_dir'] ? $_CONFIG['directories']['sys_dir'].'/templates' : $_CONFIG['directories']['smarty_templates_dir']);
-
-// Doadowanie reszty domylnych wartoci
 
 foreach(lms_parse_ini_file($_CONFIG['directories']['lib_dir'].'/config_defaults.ini', TRUE) as $section => $values)
 	foreach($values as $key => $val)
 		if(! isset($_CONFIG[$section][$key]))
 			$_CONFIG[$section][$key] = $val;
 
-// Przepisanie wartoci zmiennych parametrw bazy danych
-
 $_DBTYPE = $_CONFIG['database']['type'];
 $_DBHOST = $_CONFIG['database']['host'];
 $_DBUSER = $_CONFIG['database']['user'];
 $_DBPASS = $_CONFIG['database']['password'];
 $_DBNAME = $_CONFIG['database']['database'];
 
-// Wczytanie niezbdnych libw.
+// Init database 
 
-require_once($_CONFIG['directories']['lib_dir'].'/common.php');
 require_once($_CONFIG['directories']['lib_dir'].'/LMSDB.php');
-require_once($_CONFIG['directories']['lib_dir'].'/LMS.class.php');
-require_once($_CONFIG['directories']['lib_dir'].'/language.php');
-
-// Zainicjowanie bazy danych.
 
 $DB = DBInit($_DBTYPE, $_DBHOST, $_DBUSER, $_DBPASS, $_DBNAME);
 
-// Nie uywamy raczej sesji. ;)
+// Enable data encoding conversion if needed 
 
-$SESSION = NULL;
+require_once($_CONFIG['directories']['lib_dir'].'/dbencoding.php');
 
-// Inicjacja obiektu LMS'a.
+// Read configuration of LMS-UI from database
 
-$LMS = new LMS($DB, $SESSION, $_CONFIG);
+if($cfg = $DB->GetAll('SELECT section, var, value FROM uiconfig WHERE disabled=0'))
+	foreach($cfg as $row)
+		$_CONFIG[$row['section']][$row['var']] = $row['value'];
+
+// Include required files (including sequence is important)
+
+require_once($_CONFIG['directories']['lib_dir'].'/language.php');
+require_once($_CONFIG['directories']['lib_dir'].'/common.php');
+require_once($_CONFIG['directories']['lib_dir'].'/LMS.class.php');
+
+$_SESSION = NULL;
+
+$LMS = new LMS($DB, $_SESSION, $_CONFIG);
+$LMS->lang = $_language;
 
 ?>
