@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,10 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: sql.php,v 1.7.2.2 2005/01/01 19:19:07 alec Exp $
+ *  $Id: sql.php,v 1.10.2.1 2005/05/13 20:09:48 alec Exp $
  */
+
+include('sqllang.php');
  
-$layout['pagetitle'] = 'SQL';
+$layout['pagetitle'] = trans('SQL');
 
 if($query = $_POST['query'])
 {
@@ -39,7 +41,7 @@ if($query = $_POST['query'])
 
 	if(sizeof($LMS->DB->errors)) 
 	{
-		$error['query'] = 'Zapytanie nie jest poprawne!';
+		$error['query'] = trans('Query is not correct!');
 		$SMARTY->assign('error', $error);
 		$SMARTY->assign('query', $query);
 		$SMARTY->display('sql.html');	
@@ -100,7 +102,7 @@ if($query = $_POST['query'])
 	$SMARTY->assign('colnames', $colnames);
 	$SMARTY->assign('executetime', $duration);
 	$SMARTY->assign('result', $result);
-	$layout['pagetitle'] = 'SQL - Wyniki zapytania';
+	$layout['pagetitle'] = trans('SQL - Query Results');
 }
 
 $SMARTY->assign('query', $query);
