@@ -3,6 +3,10 @@ struct net
 	unsigned char *name;
 	unsigned char *domain;
 	unsigned char *interface;
+	unsigned char *gateway;
+	unsigned char *dns;
+	unsigned char *dns2;
+	unsigned char *wins;
 	unsigned long address;
 	unsigned long mask;
 };
@@ -21,6 +25,8 @@ struct hostfile_module
 	unsigned char *append;
 	unsigned char *grant;
 	unsigned char *deny;
+	unsigned char *grant_pub;
+	unsigned char *deny_pub;
 	unsigned char *file;
 	unsigned char *command;
 	unsigned char *networks;
