@@ -1,5 +1,5 @@
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -19,48 +19,50 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: system.c,v 1.1.2.2 2005/01/01 19:19:12 alec Exp $
+ *  $Id: system.c,v 1.5.2.2 2005/05/17 19:49:13 alec Exp $
  */
+
 #include <stdio.h>
+#include <stdlib.h>
 #include <syslog.h>
 #include <string.h>
 
-#include "almsd.h"
+#include "lmsd.h"
 #include "system.h"
 
 void reload(GLOBAL *g, struct system_module *s)
 {
-	system(s->command);
+	if(*s->sql)
+	{
+		g->db_exec(g->conn, s->sql);
+	}
+
+	if(*s->command)
+	{
+		system(s->command);
+	}
 #ifdef DEBUG1
 	syslog(LOG_INFO, "DEBUG: [%s/system] reloaded", s->base.instance);
 #endif
 	free(s->command);
+	free(s->sql);
 }
 
 struct system_module * init(GLOBAL *g, MODULE *m)
 {
 	struct system_module *s;
-	unsigned char *instance, *a;
-	dictionary *ini;
 	
 	if(g->api_version != APIVERSION) 
-	    return (NULL);
-	
-	instance = m->instance;
+	{
+	        return (NULL);
+	}
 	
 	s = (struct system_module *) realloc(m, sizeof(struct system_module));
 	
 	s->base.reload = (void (*)(GLOBAL *, MODULE *)) &reload;
-	s->base.instance = strdup(instance);
 
-	ini = g->iniparser_load(g->inifile);
-
-	a = g->str_concat(instance, ":command");
-	s->command = strdup(g->iniparser_getstring(ini, a, ""));
-	
-	g->iniparser_freedict(ini);
-	free(a);
-	free(instance);
+	s->command = strdup(g->config_getstring(s->base.ini, s->base.instance, "command", ""));
+	s->sql = strdup(g->config_getstring(s->base.ini, s->base.instance, "sql", ""));
 #ifdef DEBUG1
 	syslog(LOG_INFO,"DEBUG: [%s/system] initialized", s->base.instance);
 #endif	
