@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB.php,v 1.6.2.2 2005/01/01 19:19:15 alec Exp $
+ *  $Id: LMSDB.php,v 1.9.2.1 2005/05/13 20:09:53 alec Exp $
  */
 
 /*
@@ -31,7 +31,7 @@
  * This file include required files and do some nasty things ;>
  */
 
-define(LMSDB_DIR,dirname(__FILE__));
+define('LMSDB_DIR',dirname(__FILE__));
 
 require_once(LMSDB_DIR.'/LMSDB_common.class.php');
 
