@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_common.class.php,v 1.26.2.2 2005/01/01 19:19:15 alec Exp $
+ *  $Id: LMSDB_common.class.php,v 1.34.2.2 2005/06/10 07:15:50 alec Exp $
  */
 
 /*
@@ -30,8 +30,8 @@
 
 Class LMSDB_common
 {
-	var $_version = '1.4.5 Persus';
-	var $_revision = '$Revision: 1.26.2.2 $';
+	var $_version = '1.6.1 Ishta';
+	var $_revision = '$Revision: 1.34.2.2 $';
 	
 	// Driver powinien nadpisa t zmienn wartoci TRUE, eby
 	// funkcja inicjujca baze danych wiedziaa e driver si poprawnie
@@ -51,6 +51,7 @@ Class LMSDB_common
 	var $_result = NULL;
 
 	var $errors = array();
+	var $debug = FALSE;
 
 	function LMSDB_common()
 	{
@@ -60,8 +61,22 @@ Class LMSDB_common
 	
 	function Connect($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		// Inicjuje poczenie do bazy danych
-		return $this->_driver_connect($dbhost,$dbuser,$dbpasswd,$dbname);
+		if(method_exists($this, '_driver_shutdown'))
+			register_shutdown_function(array($this, '_driver_shutdown'));
+		
+		// Inicjuje poczenie do bazy danych, nie musimy zwraca
+		// dblinka na zewntrz gdy jest to niepotrzebne.
+		
+		if($this->_driver_connect($dbhost,$dbuser,$dbpasswd,$dbname))
+			return $this->_dblink;
+		else
+		{
+			$this->errors[] = array(
+					'query' => 'database connect',
+					'error' => $this->_driver_geterror(),
+					);
+			return FALSE;
+		}
 	}
 
 	function Destroy()
@@ -71,14 +86,16 @@ Class LMSDB_common
 
 	function Execute($query, $inputarray = NULL)
 	{
-	//	echo $this->_query_parser($query,$inputarray).'<HR>';
-		if(! $this->_driver_execute($this->_query_parser($query,$inputarray)))
-		{
+		if(! $this->_driver_execute($this->_query_parser($query, $inputarray)))
 			$this->errors[] = array(
 					'query' => $this->_query,
 					'error' => $this->_driver_geterror()
 					);
-		}
+		elseif($this->debug)
+			$this->errors[] = array(
+					'query' => $this->_query,
+					'error' => 'DEBUG: NOERROR'
+					);
 		return $this->_driver_affected_rows();
 	}
 
@@ -89,7 +106,7 @@ Class LMSDB_common
 		if($query)
 			$this->Execute($query, $inputarray);
 
-		unset($result);
+		$result = NULL;
 
 		while($row = $this->_driver_fetchrow_assoc())
 			$result[] = $row;
@@ -102,7 +119,7 @@ Class LMSDB_common
 		if($query)
 			$this->Execute($query, $inputarray);
 
-		unset($result);
+		$result = NULL;
 
 		while($row = $this->_driver_fetchrow_assoc())
 			$result[$row[$key]] = $row;
@@ -123,7 +140,7 @@ Class LMSDB_common
 		if($query)
 			$this->Execute($query, $inputarray);
 
-		unset($result);
+		$result = NULL;
 
 		while($row = $this->_driver_fetchrow_num())
 			$result[] = $row[0];
@@ -136,7 +153,7 @@ Class LMSDB_common
 		if($query)
 			$this->Execute($query, $inputarray);
 
-		unset($result);
+		$result = NULL;
 
 		list($result) = $this->_driver_fetchrow_num();
 
@@ -178,6 +195,7 @@ Class LMSDB_common
 		// najpierw sparsujmy wszystkie specjalne meta mieci.
 		$query = eregi_replace('\?NOW\?',$this->_driver_now(),$query);
 		$query = eregi_replace('\?LIKE\?',$this->_driver_like(),$query);
+
 		if($inputarray)
 		{
 			$queryelements = explode("\0",str_replace('?',"?\0",$query));
