@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_mysql.class.php,v 1.24.2.2 2005/01/01 19:19:20 alec Exp $
+ *  $Id: LMSDB_driver_mysql.class.php,v 1.32.2.1 2005/05/13 20:09:53 alec Exp $
  */
 
 /*
@@ -32,11 +32,12 @@ class LMSDB_driver_mysql extends LMSDB_common
 {
 	var $_loaded = TRUE;
 	var $_dbtype = 'mysql';
+	var $iconv = NULL;
 
-	function LMSDB_driver_mysql($dbhost,$dbuser,$dbpasswd,$dbname)
+	function LMSDB_driver_mysql($dbhost, $dbuser, $dbpasswd, $dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.24.2.2 $').')';
-		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
+		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.32.2.1 $').')';
+		$this->Connect($dbhost, $dbuser, $dbpasswd, $dbname);
 	}
 	
 	function _driver_dbversion()
@@ -44,9 +45,9 @@ class LMSDB_driver_mysql extends LMSDB_common
 		return mysql_get_server_info();
 	}
 
-	function _driver_connect($dbhost,$dbuser,$dbpasswd,$dbname)
+	function _driver_connect($dbhost, $dbuser, $dbpasswd, $dbname)
 	{
-		if($this->_dblink = mysql_connect($dbhost,$dbuser,$dbpasswd))
+		if($this->_dblink = @mysql_connect($dbhost,$dbuser,$dbpasswd))
 		{
 			$this->_dbhost = $dbhost;
 			$this->_dbuser = $dbuser;
@@ -59,19 +60,30 @@ class LMSDB_driver_mysql extends LMSDB_common
 		return $this->_dblink;
 	}
 
+	function _driver_shutdown()
+	{
+		$this->_loaded = FALSE;
+		// mysql_close($this->_dblink); - apparently, mysql_close() is automagicly called after end of the script...
+	}
+	
 	function _driver_geterror()
 	{
-		return mysql_error($this->_dblink);
+		if($this->_dblink)
+			return mysql_error($this->_dblink);
+		elseif($this->_query)
+			return 'We\'re not connected!';
+		else
+			return mysql_error();
 	}
 
 	function _driver_disconnect()
 	{
-		return mysql_close($this->_dblink);
+		return @mysql_close($this->_dblink);
 	}
 	
 	function _driver_selectdb($dbname)
 	{
-		if($result = mysql_select_db($dbname,$this->_dblink))
+		if($result = mysql_select_db($dbname, $this->_dblink))
 			$this->_dbname = $dbname;
 		return $result;
 	}
@@ -79,8 +91,11 @@ class LMSDB_driver_mysql extends LMSDB_common
 	function _driver_execute($query)
 	{
 		$this->_query = $query;
+		
+		if($this->iconv)
+			$query = iconv('UTF-8', $this->iconv, $query);
 
-		if($this->_result = mysql_query($query,$this->_dblink))
+		if($this->_result = @mysql_query($query, $this->_dblink))
 			$this->_error = FALSE;
 		else
 			$this->_error = TRUE;
@@ -90,7 +105,19 @@ class LMSDB_driver_mysql extends LMSDB_common
 	function _driver_fetchrow_assoc()
 	{
 		if(! $this->_error)
-			return mysql_fetch_array($this->_result,MYSQL_ASSOC);
+		{
+			$result =  mysql_fetch_array($this->_result, MYSQL_ASSOC);
+			
+			if(!$this->iconv)
+				return $result;
+			else
+			{
+				if($result)
+					foreach($result as $idx => $val)
+						$result[$idx] = iconv($this->iconv, 'UTF-8', $val);
+				return $result;
+			}
+		}
 		else
 			return FALSE;
 	}
@@ -98,7 +125,19 @@ class LMSDB_driver_mysql extends LMSDB_common
 	function _driver_fetchrow_num()
 	{
 		if(! $this->_error)
-			return mysql_fetch_array($this->_result,MYSQL_NUM);
+		{
+			$result = mysql_fetch_array($this->_result, MYSQL_NUM);
+			
+			if(!$this->iconv)
+				return $result;
+			else
+			{
+				if($result)
+					foreach($result as $idx => $val)
+						$result[$idx] = iconv($this->iconv, 'UTF-8', $val);
+				return $result;
+			}
+		}
 		else
 			return FALSE;
 	}
@@ -123,13 +162,13 @@ class LMSDB_driver_mysql extends LMSDB_common
 
 	function _driver_concat($input)
 	{
-		$return = implode(', ',$input);
+		$return = implode(', ', $input);
 		return 'CONCAT('.$return.')';
 	}
 
 	function _driver_listtables()
 	{
-		$this->_result = mysql_list_tables($this->_dbname,$this->_dblink);
+		$this->_result = mysql_list_tables($this->_dbname, $this->_dblink);
 		return $this->GetCol();
 	}
 
