@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_postgres.class.php,v 1.18.2.2 2005/01/01 19:19:20 alec Exp $
+ *  $Id: LMSDB_driver_postgres.class.php,v 1.26.2.1 2005/05/13 20:09:53 alec Exp $
  */
 
 /*
@@ -35,14 +35,13 @@ class LMSDB_driver_postgres extends LMSDB_common
 
 	function LMSDB_driver_postgres($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.18.2.2 $').')';
+		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.26.2.1 $').')';
 		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
 
 	function _driver_dbversion()
 	{
-		list($var1, $var2) = explode(' ',$this->GetOne("SELECT version()"));
-		return $var2;
+		return $this->GetOne("SELECT substring(substring(version() from 1+position(' ' in version())) for position(' ' in substring(version() from 1+position(' ' in version())))-1)");
 	}
 
 	function _driver_connect($dbhost,$dbuser,$dbpasswd,$dbname)
@@ -63,6 +62,7 @@ class LMSDB_driver_postgres extends LMSDB_common
 		}
 		else
 			$this->_error = TRUE;
+
 		return $this->_dblink;
 	}
 
