@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,17 +21,18 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_sqlite.class.php,v 1.6.2.2 2005/01/01 19:19:20 alec Exp $
+ *  $Id: LMSDB_driver_sqlite.class.php,v 1.8.2.2 2005/05/28 07:48:14 alec Exp $
  */
 
 class LMSDB_driver_sqlite extends LMSDB_common
 {
 	var $_loaded = TRUE;
 	var $_dbtype = 'sqlite';
+	var $iconv = NULL;
 
 	function LMSDB_driver_sqlite($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.6.2.2 $').')';
+		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.8.2.2 $').')';
 		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
 
@@ -71,6 +72,9 @@ class LMSDB_driver_sqlite extends LMSDB_common
 	{
 		$this->_query = $query;
 
+		if($this->iconv)
+			$query = iconv('UTF-8', $this->iconv, $query);
+
 		if($this->_result = sqlite_query($this->_dblink,$query))
 			$this->_error = FALSE;
 		else
@@ -82,7 +86,19 @@ class LMSDB_driver_sqlite extends LMSDB_common
 	function _driver_fetchrow_assoc()
 	{
 		if(! $this->_error)
-			return sqlite_fetch_array($this->_result,SQLITE_ASSOC);
+		{
+			$result = sqlite_fetch_array($this->_result,SQLITE_ASSOC);
+		
+			if(!$this->iconv)
+				return $result;
+			else
+			{
+				if($result)
+					foreach($result as $idx => $val)
+						$result[$idx] = iconv($this->iconv, 'UTF-8', $val);
+				return $result;
+			}
+		}
 		else
 			return FALSE;
 	}
@@ -90,7 +106,19 @@ class LMSDB_driver_sqlite extends LMSDB_common
 	function _driver_fetchrow_num()
 	{
 		if(! $this->_error)
-			return sqlite_fetch_array($this->_result,SQLITE_NUM);
+		{
+			$result = sqlite_fetch_array($this->_result,SQLITE_NUM);
+		
+			if(!$this->iconv)
+				return $result;
+			else
+			{
+				if($result)
+					foreach($result as $idx => $val)
+						$result[$idx] = iconv($this->iconv, 'UTF-8', $val);
+				return $result;
+			}
+		}
 		else
 			return FALSE;
 	}
@@ -133,7 +161,7 @@ class LMSDB_driver_sqlite extends LMSDB_common
 	{
 		return $this->Execute('COMMIT');
 	}
-	
+
 	function _driver_udf_functions()
 	{
 		sqlite_create_function($this->_dblink, 'inet_ntoa','long2ip',1);
@@ -141,7 +169,6 @@ class LMSDB_driver_sqlite extends LMSDB_common
 		sqlite_create_function($this->_dblink, 'upper','strtoupper',1);
 		sqlite_create_function($this->_dblink, 'lower','strtolower',1);
 		sqlite_create_function($this->_dblink, 'floor','floor',1);
-		sqlite_create_function($this->_dblink, 'random','sql_random');
 	}
 }
 
