@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,19 +21,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: checkdirs.php,v 1.21.2.2 2005/01/01 19:19:22 alec Exp $
+ *  $Id: checkdirs.php,v 1.26.2.1 2005/05/13 20:09:53 alec Exp $
  */
 
 if(!is_dir($_SMARTY_COMPILE_DIR))
-	die('Brakuje mi katalogu <B>'.$_SMARTY_COMPILE_DIR.'</B> - bd wdziczny jak kto go utworzy.');
+	die('Missing directory <B>'.$_SMARTY_COMPILE_DIR.'</B>. Can enybody make them?');
 
 if(!is_writable($_SMARTY_COMPILE_DIR))
-	die('Nie mog zapisywa do katalogu <B>'.$_SMARTY_COMPILE_DIR.'</B> - mgby wykona komend:<BR><pre>chown '.posix_geteuid().'.'.posix_getegid().' '.$_SMARTY_COMPILE_DIR."\nchmod 755 ".$_SMARTY_COMPILE_DIR.'</pre><BR>Pomoe mi to poprawnie dziaa. Dziki.');
+	die('Can\'t write to directory <B>'.$_SMARTY_COMPILE_DIR.'</B>. Can you run: <BR><PRE>chown '.posix_geteuid().'.'.posix_getegid().' '.$_SMARTY_COMPILE_DIR."\nchmod 755 ".$_SMARTY_COMPILE_DIR.'</PRE>This helps me to work. Thanks.');
 
 if(!is_dir($_BACKUP_DIR))
-	die('Brakuje mi katalogu <B>'.$_BACKUP_DIR.'</B> - bd wdziczny jak kto6 go utworzy.');
+	die('Missing directory <B>'.$_BACKUP_DIR.'</B>. Can enybody make them?');
 	
 if(!is_writable($_BACKUP_DIR))
-	die('Nie mog zapisywa do katalogu <B>'.$_BACKUP_DIR.'</B> - mgby wykona komend:<BR><pre>chown '.posix_geteuid().'.'.posix_getegid().' '.$_BACKUP_DIR."\nchmod 755 ".$_BACKUP_DIR.'</pre><BR>Pomoe mi to poprawnie dziaa. Dziki.');
+	die('Can\'t write to directory <B>'.$_BACKUP_DIR.'</B>. Can you run: <BR><PRE>chown '.posix_geteuid().'.'.posix_getegid().' '.$_BACKUP_DIR."\nchmod 755 ".$_BACKUP_DIR.'</PRE>This helps me to work. Thanks.');
 
 ?>
