@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,26 +21,40 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: upgradedb.php,v 1.27.2.2 2005/01/01 19:19:27 alec Exp $
+ *  $Id: upgradedb.php,v 1.62.2.1 2005/05/13 20:09:54 alec Exp $
  */
 
-define(DBVERSION, '2004090800'); // here should be always the newest version of database!
-// it placed here to avoid read disk every time when we call this file.
+define('DBVERSION', '2005042400'); // here should be always the newest version of database!
+				 // it placed here to avoid read disk every time when we call this file.
 
 /*
  * This file contains procedures for upgradeing automagicly database.
  */
 
+function getdir($pwd = './', $pattern = '^.*$')
+{
+	if ($handle = @opendir($pwd))
+	{
+		while (($file = readdir($handle)) !== FALSE)
+			if(ereg($pattern,$file))
+				$files[] = $file;
+		closedir($handle);
+	}
+	return $files;
+}
+
 if($dbversion = $DB->GetOne('SELECT keyvalue FROM dbinfo WHERE keytype = ?',array('dbversion')))
 	if(DBVERSION > $dbversion)
 	{
+		$lastupgrade = $dbversion;
+		
 		$upgradelist = getdir($_LIB_DIR.'/upgradedb/', '^'.$_DBTYPE.'.[0-9]{10}.php$');
 		if(sizeof($upgradelist))
 			foreach($upgradelist as $upgrade)
 			{
 				$upgradeversion = ereg_replace('^'.$_DBTYPE.'.([0-9]{10}).php$','\1',$upgrade);
 				
-				if($upgradeversion > $dbversion)
+				if($upgradeversion > $dbversion && $upgradeversion <= DBVERSION)
 					$pendingupgrades[] = $upgradeversion;
 			}
 			
@@ -48,12 +62,16 @@ if($dbversion = $DB->GetOne('SELECT keyvalue FROM dbinfo WHERE keytype = ?',arra
 		{
 			sort($pendingupgrades);
 			foreach($pendingupgrades as $upgrade)
-			{
+			{	
 				include($_LIB_DIR.'/upgradedb/'.$_DBTYPE.'.'.$upgrade.'.php');
+				if(!sizeof($DB->errors))
+					$lastupgrade = $upgrade;
+				else
+					break;
 			}
 		}
 	}
 
-$layout['dbschversion'] = DBVERSION;
+$layout['dbschversion'] = isset($lastupgrade) ? $lastupgrade : DBVERSION;
 
 ?>
