@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,18 +21,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: adminedit.php,v 1.30.2.3 2005/02/26 17:35:03 alec Exp $
+ *  $Id: adminedit.php,v 1.42.2.2 2005/05/20 11:44:37 kondi Exp $
  */
 
 if(!$LMS->AdminExists($_GET['id']))
 {
-	header("Location: ?m=adminlist");
-	die;
+	$SESSION->redirect('?m=adminlist');
 }
 
-$admininfo=$_POST['admininfo'];
+$admininfo = isset($_POST['admininfo']) ? $_POST['admininfo'] : FALSE;
 
-if(isset($admininfo))
+if($admininfo)
 {
 	$acl = $_POST['acl'];
 	$admininfo['id'] = $_GET['id'];
@@ -40,28 +39,31 @@ if(isset($admininfo))
 	foreach($admininfo as $key => $value)
 		$admininfo[$key] = trim($value);
 
-	if($admininfo['login'] == "")
-		$error['login'] = "Login nie moe by pusty!";
-	elseif(!eregi("^[a-z0-9.-_]+$",$admininfo['login']))
-		$error['login'] = "Login zawiera niepoprawne znaki!";
+	if($admininfo['login'] == '')
+		$error['login'] = trans('Login can\'t be empty!');
+	elseif(!eregi('^[a-z0-9.-_]+$',$admininfo['login']))
+		$error['login'] = trans('Login contains forbidden characters!');
 	elseif($LMS->GetAdminIDByLogin($admininfo['login']) && $LMS->GetAdminIDByLogin($admininfo['login']) != $_GET['id'])
-		$error['login'] = "Konto o podanym loginie istnieje lub login ten zosta ju wykorzystany w przeszoci!";
+		$error['login'] = trans('User with specified login exists or this login was used in the past!');
 
-	if($admininfo['name'] == "")
-		$error['name'] = "Pole 'imi i nazwisko' nie moe by puste!";
+	if($admininfo['name'] == '')
+		$error['name'] = trans('You have to enter first and lastname!');
 
-	if($admininfo['email']!="" && !check_email($admininfo['email']))
-		$error['email'] = "Podany email nie wydaje si by poprawny!";
+	if($admininfo['email']!='' && !check_email($admininfo['email']))
+		$error['email'] = trans('E-mail isn\'t correct!');
 				
-
 	// zrbmy mask ACL...
 
+	$mask = '';
+	$outmask = '';
+	
 	for($i=0;$i<256;$i++)
-		$mask .= "0";
+		$mask .= '0';
 	
 	foreach($access['table'] as $idx => $row)
-		if($acl[$idx]=="1")
-			$mask[255-$idx] = "1";
+		if(isset($acl[$idx]))
+			if($acl[$idx]=='1')
+				$mask[255-$idx] = '1';
 	for($i=0;$i<256;$i += 4)
 		$outmask = $outmask . dechex(bindec(substr($mask,$i,4)));
 
@@ -70,8 +72,7 @@ if(isset($admininfo))
 	if(!$error)
 	{
 		$LMS->AdminUpdate($admininfo);
-		header("Location: ?m=admininfo&id=".$admininfo['id']);
-		die;
+		$SESSION->redirect('?m=admininfo&id='.$admininfo['id']);
 	}
 
 }
@@ -80,7 +81,7 @@ foreach($LMS->GetAdminInfo($_GET['id']) as $key => $value)
 	if(!isset($admininfo[$key]))
 		$admininfo[$key] = $value;
 
-$layout['pagetitle'] = "Edycja danych administratora: ".$LMS->GetAdminName($_GET['id']);
+$layout['pagetitle'] = trans('User Edit: $0', $admininfo['login']);
 
 $rights = $LMS->GetAdminRights($_GET['id']);
 
@@ -92,6 +93,9 @@ foreach($access['table'] as $idx => $row)
 			$row['enabled']=TRUE;
 	$accesslist[] = $row;
 }
+
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
+
 $SMARTY->assign('accesslist',$accesslist);
 $SMARTY->assign('admininfo',$admininfo);
 $SMARTY->assign('unlockedit',TRUE);
