@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,25 +21,26 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: admininfo.php,v 1.24.2.2 2005/01/01 19:19:44 alec Exp $
+ *  $Id: admininfo.php,v 1.33.2.1 2005/05/13 20:10:01 alec Exp $
  */
 
 if(!$LMS->AdminExists($_GET['id']))
 {
-	header("Location: ?m=adminlist");
-	die;
+	$SESSION->redirect('?m=adminlist');
 }
 
-$layout['pagetitle'] = "Informacje o administratorze: ".$LMS->GetAdminName($_GET['id']);
-$admininfo=$LMS->GetAdminInfo($_GET['id']);
+$admininfo = $LMS->GetAdminInfo($_GET['id']);
+$layout['pagetitle'] = trans('User Info: $0', $admininfo['login']);
 
 $rights = $LMS->GetAdminRights($_GET['id']);
 foreach($rights as $right)
 	if($access['table'][$right]['name'])
 		$accesslist[] = $access['table'][$right]['name'];
 
-$SMARTY->assign('admininfo',$admininfo);
-$SMARTY->assign('accesslist',$accesslist);
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
+
+$SMARTY->assign('admininfo', $admininfo);
+$SMARTY->assign('accesslist', $accesslist);
 $SMARTY->display('admininfo.html');
 
-?>
\ No newline at end of file
+?>
