@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,12 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: adminlist.php,v 1.18.2.2 2005/01/01 19:19:45 alec Exp $
+ *  $Id: adminlist.php,v 1.23.2.1 2005/05/13 20:10:01 alec Exp $
  */
 
-$layout['pagetitle'] = "Administratorzy";
+$layout['pagetitle'] = trans('Users List');
+
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('adminslist',$LMS->GetAdminList());
 $SMARTY->display('adminlist.html');
 
-?>
\ No newline at end of file
+?>
