@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,42 +21,43 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: adminpasswd.php,v 1.24.2.2 2005/01/01 19:19:45 alec Exp $
+ *  $Id: adminpasswd.php,v 1.34.2.2 2005/05/20 11:44:38 kondi Exp $
  */
 
-$passwd = $_POST['passwd'];
-
-$id = (isset($_GET['id'])) ? $_GET['id'] : $SESSION->id;
+$id = (isset($_GET['id'])) ? $_GET['id'] : $AUTH->id;
 
 if($LMS->AdminExists($id))
 {
-	if(isset($passwd))
+	$error = FALSE;
+
+	if(isset($_POST['passwd']))
 	{
-		if($passwd['passwd'] == "" || $passwd['confirm'] == "")
-			$error['password'] .= "Haso nie moe by puste!<BR>";
+		$passwd = $_POST['passwd'];
+		
+		if($passwd['passwd'] == '' || $passwd['confirm'] == '')
+			$error['password'] = trans('Empty passwords are not allowed!').'<BR>';
 		
 		if($passwd['passwd'] != $passwd['confirm'])
-			$error['password'] .= "Podane hasa si rni!";
+			$error['password'] = trans('Passwords does not match!');
 		
 		if(!$error)
 		{
-			$LMS->SetAdminPassword($id,$passwd['passwd']);
-			header("Location: ?m=welcome");
+			$LMS->SetAdminPassword($id, $passwd['passwd']);
+			header('Location: ?'. $SESSION->get('backto'));
 		}
 	}
 
 	$passwd['realname'] = $LMS->GetAdminName($id);
 	$passwd['id'] = $id;
-	$layout['pagetitle'] = "Zmiana hasa dla ".$passwd['realname'];
-	$SMARTY->assign('error',$error);
-	$SMARTY->assign('passwd',$passwd);
+	$layout['pagetitle'] = trans('Password Change for User $0',$passwd['realname']);
+	$SMARTY->assign('error', $error);
+	$SMARTY->assign('passwd', $passwd);
 	$SMARTY->display('adminpasswd.html');
 
 }
 else
 {
-	header("Location: ?m=".$_SESSION['lastmodule']);
-	die;
+	$SESSION->redirect('?m='. $SESSION->get('lastmodule'));
 }
 
-?>
\ No newline at end of file
+?>
