@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancedel.php,v 1.1.2.2 2005/01/01 19:19:46 alec Exp $
+ *  $Id: balancedel.php,v 1.7.2.1 2005/05/13 20:10:01 alec Exp $
  */
 
 if (sizeof($_POST['marks']))
@@ -36,6 +36,6 @@ if (sizeof($_POST['marks']))
 	}
 }
 
-header("Location: ?".$_SESSION['backto']);
+header('Location: ?'.$SESSION->get('backto'));
 
 ?>
