@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancelist.php,v 1.34.2.2 2005/01/01 19:19:46 alec Exp $
+ *  $Id: balancelist.php,v 1.40.2.1 2005/05/13 20:10:01 alec Exp $
  */
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $balancelist = $LMS->GetBalanceList();
 
@@ -44,7 +44,7 @@ $pagelimit = $LMS->CONFIG['phpui']['balancelist_pagelimit'];
 $page = (! $_GET['page'] ? ceil($listdata['totalpos']/$pagelimit) : $_GET['page']); 
 $start = ($page - 1) * $pagelimit;
 
-$layout['pagetitle'] = "Bilans finansowy";
+$layout['pagetitle'] = trans('Balance Sheet');
 
 $SMARTY->assign('balancelist',$balancelist);
 $SMARTY->assign('listdata',$listdata);
