@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,18 +21,18 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancenew.php,v 1.20.2.2 2005/01/01 19:19:47 alec Exp $
+ *  $Id: balancenew.php,v 1.25.2.1 2005/05/13 20:10:01 alec Exp $
  */
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
-$layout['pagetitle'] = "Nowa operacja finansowa";
-$SMARTY->assign('operation',$_SESSION['addtype']);
-$SMARTY->assign('comment',$_SESSION['addbc']);
-$SMARTY->assign('taxvalue', $_SESSION['addbtax']);
-$SMARTY->assign('time', $_SESSION['addbt']);
-$SMARTY->assign('value', $_SESSION['addbv']);
+$layout['pagetitle'] = trans('New Balance');
+$SMARTY->assign('operation',$SESSION->get('addtype'));
+$SMARTY->assign('comment', $SESSION->get('addbc'));
+$SMARTY->assign('taxvalue', $SESSION->get('addbtax'));
+$SMARTY->assign('time', $SESSION->get('addbt'));
+$SMARTY->assign('value', $SESSION->get('addbv'));
 $SMARTY->assign('users',$LMS->GetUserNames());
 $SMARTY->display('balancenew.html');
 
-?>
\ No newline at end of file
+?>
