@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,33 +21,57 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: chooseip.php,v 1.25.2.2 2005/01/01 19:19:47 alec Exp $
+ *  $Id: chooseip.php,v 1.36.2.1 2005/05/13 20:10:01 alec Exp $
  */
 
+$layout['pagetitle'] = trans('Select IP address');
+
+$networks = $LMS->GetNetworks();
+
 $p = $_GET['p'];
 
 if(!isset($p))
-	$js = "var targetfield = window.opener.targetfield;";
-if($p == "main")
-	$js = "var targetfield = parent.targetfield;";
-
-$networks = $LMS->GetNetworks();
+	$js = 'var targetfield = window.opener.targetfield;';
+if($p == 'main')
+	$js = 'var targetfield = parent.targetfield;';
 
 if (isset($_POST['netid']))
-    $netid= $_POST['netid'];
+    $netid = $_POST['netid'];
 elseif (isset($_GET['netid']))
     $netid = $_GET['netid'];
-elseif (isset($_SESSION['netid']))
-    $netid = $_SESSION['netid'];
+elseif ($SESSION->is_set('netid'))
+    $SESSION->restore('netid', $netid);
 else
     $netid = $networks[0]['id'];
 
-$_SESSION['netid'] = $netid;
+if (isset($_POST['page']))
+    $page = $_POST['page'];
+elseif (isset($_GET['page']))
+    $page = $_GET['page'];
+elseif ($SESSION->is_set('ntlp.page.'.$netid))
+    $SESSION->restore('ntlp.page.'.$netid, $page);
+else
+    $page = 1;
 
-if($p == "main")
-	$network = $LMS->GetNetwork($netid);
+$SESSION->save('netid', $netid);
+$SESSION->save('ntlp.page.'.$netid, $page);
 
-$layout['pagetitle'] = "Wybierz adres IP";
+if($p == 'main')
+{
+	$network = $LMS->GetNetworkRecord($netid, $page, $LMS->CONFIG['phpui']['networkhosts_pagelimit']);
+	$SESSION->save('ntlp.pages.'.$netid, $network['pages']);
+}
+
+if($p == 'down' || $p == 'top')
+{
+	$SESSION->restore('ntlp.page.'.$netid, $network['page']);
+	$SESSION->restore('ntlp.pages.'.$netid, $network['pages']);
+	if (!isset($network['pages'])) 
+	{
+		$network = $LMS->GetNetworkRecord($netid, $page, $LMS->CONFIG['phpui']['networkhosts_pagelimit']);
+		$SESSION->save('ntlp.pages.'.$netid, $network['pages']);
+	}
+}
 
 $SMARTY->assign('part',$p);
 $SMARTY->assign('js',$js);
