@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,20 +21,20 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: choosemac.php,v 1.15.2.2 2005/01/01 19:19:47 alec Exp $
+ *  $Id: choosemac.php,v 1.18.2.1 2005/05/13 20:10:01 alec Exp $
  */
 
-$layout['pagetitle'] = "Wybierz adres MAC";
+$layout['pagetitle'] = trans('Select MAC address');
 
 $p = $_GET['p'];
 $netid = $_POST['netid'];
 
 if(!isset($p))
-	$js = "var targetfield = window.opener.targetfield;";
-if($p == "main")
-	$js = "var targetfield = parent.targetfield;";
+	$js = 'var targetfield = window.opener.targetfield;';
+if($p == 'main')
+	$js = 'var targetfield = parent.targetfield;';
 
-if($p == "main")
+if($p == 'main')
 {
 	$maclist = $LMS->GetMACs();
 	if($LMS->CONFIG['phpui']['arpd_servers'])
@@ -43,7 +43,7 @@ if($p == "main")
 		foreach($servers as $server)
 		{
 			list($addr,$port) = split(':',$server);
-			if($port == "")
+			if($port == '')
 				$port = 1029;
 			$maclist = array_merge($maclist,$LMS->GetRemoteMACs($addr,$port));
 		}
