@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,43 +21,41 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: chpasswd.php,v 1.15.2.2 2005/01/01 19:19:47 alec Exp $
+ *  $Id: chpasswd.php,v 1.25.2.2 2005/05/20 11:44:39 kondi Exp $
  */
 
-$passwd = $_POST['passwd'];
-
-$id = $SESSION->id;
+$id = $AUTH->id;
 
 if($LMS->AdminExists($id))
 {
-	if(isset($passwd))
+	if(isset($_POST['passwd']))
 	{
-		if($passwd['passwd'] == "" || $passwd['confirm'] == "")
-			$error['password'] .= "Haso nie moe by puste!<BR>";
+		$passwd = $_POST['passwd'];
+		
+		if($passwd['passwd'] == '' || $passwd['confirm'] == '')
+			$error['password'] = trans('Empty passwords are not allowed!');
 		
 		if($passwd['passwd'] != $passwd['confirm'])
-			$error['password'] .= "Podane hasa si rni!";
+			$error['password'] = trans('Passwords does not match!');
 		
 		if(!$error)
 		{
 			$LMS->SetAdminPassword($id,$passwd['passwd']);
-			header("Location: ?m=welcome");
+			header('Location: ?'.$SESSION->get('backto'));
 		}
 	}
 
-	$passwd['realname'] = $LMS->GetAdminName($id);
 	$passwd['id'] = $id;
-	$layout['pagetitle'] = "Zmiana hasa";
-	$SMARTY->assign('error',$error);
-	$SMARTY->assign('passwd',$passwd);
-	$SMARTY->assign('target',"?m=chpasswd");
+	$layout['pagetitle'] = trans('Password Change');
+	$SMARTY->assign('error', $error);
+	$SMARTY->assign('passwd', $passwd);
+	$SMARTY->assign('target', '?m=chpasswd');
 	$SMARTY->display('adminpasswd.html');
 
 }
 else
 {
-	header("Location: ?m=".$_SESSION['lastmodule']);
-	die;
+	$SESSION->redirect('?m='.$SESSION->get('lastmodule'));
 }
 
-?>
\ No newline at end of file
+?>
