@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: confirm.php,v 1.1.2.2 2005/01/01 19:19:47 alec Exp $
+ *  $Id: confirm.php,v 1.4.2.1 2005/05/13 20:10:02 alec Exp $
  */
 
-$layout['pagetitle'] = 'Pytanie';
+$layout['pagetitle'] = trans('Question');
 
 $SMARTY->assign('text', stripslashes($_GET['text']));
 $SMARTY->assign('href', $_GET['link']);
