@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,40 +21,37 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: contract.php,v 1.2.2.3 2005/01/01 19:19:48 alec Exp $
+ *  $Id: contract.php,v 1.9.2.2 2005/06/02 16:01:37 alec Exp $
  */
 
-if(!eregi("^[0-9]+$",$_GET['id']))
+if(!eregi('^[0-9]+$',$_GET['id']))
 {
-	header('Location: ?m=userlist');
-	die;
+	$SESSION->redirect('?m=userlist');
 }
 
 if($LMS->UserExists($_GET['id']) == 0)
 {
-	header('Location: ?m=userlist');
-	die;
+	$SESSION->redirect('?m=userlist');
 }
 
 $userinfo = $LMS->GetUser($_GET['id']);
-$assigments = $LMS->GetUserAssignments($_GET['id']);
+$assignments = $LMS->GetUserAssignments($_GET['id']);
 $usernodes = $LMS->GetUserNodes($_GET['id']);
 $tariffs = $LMS->GetTariffs();
-$userinfo['username'] = ucwords(strtolower($userinfo['username']));
 $usernodes['ownerid'] = $_GET['id'];
 
 $SMARTY->assign(
 		array(
 			'usernodes' => $usernodes,
-			'balancelist' => $balancelist,
-			'assignments' => $assigments,
-			'usergroups' => $usergroups,
-			'otherusergroups' => $otherusergroups,
-			'error' => $error,
+			'assignments' => $assignments,
 			'userinfo' => $userinfo,
 			'tariffs' => $tariffs
 		     )
 		);
-$SMARTY->display('contract.html');
+
+if($_POST['templ'])
+	$SMARTY->display($_POST['templ']);
+else
+	$SMARTY->display($LMS->CONFIG['phpui']['contract_template']);
 
 ?>
