@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,22 +21,32 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbdel.php,v 1.20.2.2 2005/01/01 19:19:48 alec Exp $
+ *  $Id: dbdel.php,v 1.31.2.2 2005/05/20 11:44:39 kondi Exp $
  */
 
-if($_GET['is_sure'])
+if(isset($_GET['is_sure']))
 {
-	$LMS->DatabaseDelete($_GET['db']);
-	header("Location: ?m=".$_SESSION['lastmodule']);
-	die;
-} else
+	$basename = 'lms-'.$_GET['db'];
+	
+	if(@file_exists($LMS->CONFIG['directories']['backup_dir'].'/'.$basename.'.sql'))
+	{
+		@unlink($LMS->CONFIG['directories']['backup_dir'].'/'.$basename.'.sql');
+	}
+	elseif((extension_loaded('zlib'))&&((@file_exists($LMS->CONFIG['directories']['backup_dir'].'/'.$basename.'.sql.gz'))))
+	{
+		@unlink($LMS->CONFIG['directories']['backup_dir'].'/'.$basename.'.sql.gz');
+	}
+
+	$SESSION->redirect('?m=dblist');
+} 
+else
 {
-	$layout['pagetitle'] = "Usunicie bazy danych";
+	$layout['pagetitle'] = trans('Backup Delete');
 	$SMARTY->display('header.html');
-	echo "<H1>Usunicie bazy danych</H1>";
-	echo "<p>Czy jeste pewien e chcesz usun baz danych utworzon ".date("Y/m/d H:i.s",$_GET['db'])."?</p>";
-	echo "<a href=\"?m=dbdel&db=".$_GET['db']."&is_sure=1\">Tak, jestem pewien</A>";
+	echo '<H1>'.trans('Deletion of Database Backup').'</H1>';
+	echo '<P>'.trans('Are you sure, you want to delete database backup created at $0 ?',date('Y/m/d H:i.s',$_GET['db'])).'</P>';
+	echo '<a href="?m=dbdel&db='.$_GET['db'].'&is_sure=1">'.trans('Yes, I am sure.').'</A>';
 	$SMARTY->display('footer.html');
 }
 
-?>
\ No newline at end of file
+?>
