@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,11 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbnew.php,v 1.16.2.2 2005/01/01 19:19:48 alec Exp $
+ *  $Id: dbnew.php,v 1.25.2.1 2005/05/13 20:10:02 alec Exp $
  */
 
-$LMS->DatabaseCreate();
+if (isset($_GET['gz']))
+	$LMS->DatabaseCreate(TRUE);
+else
+	$LMS->DatabaseCreate();
 
-header("Location: ?m=".$_SESSION['lastmodule']);
+header('Location: ?m=dblist');
 
-?>
\ No newline at end of file
+?>
