@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,13 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: druk.php,v 1.11.2.2 2005/01/01 19:19:49 alec Exp $
+ *  $Id: druk.php,v 1.14.2.1 2005/05/13 20:10:03 alec Exp $
  */
 
 if(! $invoice = $LMS->GetInvoiceContent($_GET['id']))
 {
-	header('Location: ?m=invoicelist');
-	die;
+	$SESSION->redirect('?m=invoicelist');
 }
 
 //echo '<PRE>';print_r($invoice);
