@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,11 +21,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicelist.php,v 1.13.2.3 2005/01/01 19:19:51 alec Exp $
+ *  $Id: invoicelist.php,v 1.24.2.1 2005/05/13 20:10:04 alec Exp $
  */
 
-$layout['pagetitle'] = 'Lista faktur';
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$layout['pagetitle'] = trans('Invoices List');
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $marks = $_POST['marks'];
 unset($marked);
@@ -33,14 +33,50 @@ if( sizeof($marks) )
 	foreach($marks as $marksid => $mark)
 		$marked[] = $mark;
 
-$invoicelist = $LMS->GetInvoicesList();
+if(isset($_POST['search']))
+	$s = $_POST['search'];
+else
+	$SESSION->restore('ils', $s);
+$SESSION->save('ils', $s);
 
-$listdata['startdate'] = $invoicelist['startdate'];
-$listdata['enddate'] = $invoicelist['enddate'];
-$listdata['startyear'] = date('Y',$listdata['startdate']);
-$listdata['endyear'] = date('Y',$listdata['enddate']);
+if(isset($_GET['o']))
+	$o = $_GET['o'];
+else
+	$SESSION->restore('ilo', $o);
+$SESSION->save('ilo', $o);
 
-unset($invoicelist['startdate'], $invoicelist['enddate']);
+if(isset($_POST['cat']))
+	$c = $_POST['cat'];
+else
+	$SESSION->restore('ilc', $c);
+$SESSION->save('ilc', $c);
+
+if(isset($_POST['group'])) {
+	$g = $_POST['group'];
+	$ge = $_POST['groupexclude'];
+} else {
+	$SESSION->restore('ilg', $g);
+	$SESSION->restore('ilge', $ge);
+}
+$SESSION->save('ilg', $g);
+$SESSION->save('ilge', $ge);
+
+if($c == 'cdate' && $s)
+{
+	list($year, $month, $day) = explode('/', $s);
+	$s = mktime(0,0,0, $month, $day, $year);
+}
+
+$invoicelist = $LMS->GetInvoicesList($s, $c, array('group' => $g, 'exclude'=> $ge), $o);
+
+$SESSION->restore('ilc', $listdata['cat']);
+$SESSION->restore('ils', $listdata['search']);
+$SESSION->restore('ilg', $listdata['group']);
+$SESSION->restore('ilge', $listdata['groupexclude']);
+$listdata['order'] = $invoicelist['order'];
+$listdata['direction'] = $invoicelist['direction'];
+unset($invoicelist['order']);
+unset($invoicelist['direction']);
 
 $listdata['totalpos'] = sizeof($invoicelist);
 
@@ -54,6 +90,7 @@ $SMARTY->assign('start',$start);
 $SMARTY->assign('page',$page);
 $SMARTY->assign('marks',$marks);
 $SMARTY->assign('marked',$marked);
+$SMARTY->assign('grouplist',$LMS->UsergroupGetAll());
 $SMARTY->assign('invoicelist',$invoicelist);
 $SMARTY->display('invoicelist.html');
 
