@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,10 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicepaid.php,v 1.5.2.2 2005/01/01 19:19:54 alec Exp $
+ *  $Id: invoicepaid.php,v 1.12.2.1 2005/05/13 20:10:04 alec Exp $
  */
 
-$invoicepaydate = $_POST['invoicepaydate'];
+if (isset($_POST['invoicepaydate']))
+	$invoicepaydate = $_POST['invoicepaydate'];
+else
+	if (isset($_POST['addbalance']['time']))
+		$invoicepaydate = $_POST['addbalance']['time'];
+
 if($invoicepaydate)
 {
         // date format 'yyyy/mm/dd hh:mm'
@@ -46,38 +51,48 @@ if ($invoiceid == 'multi')
 			if ($junk)
 				$ids[] = $markid;
 		foreach($ids as $idx => $invoiceid)
-			if (!$LMS->IsInvoicePaid($invoiceid) && $invoicecontent = $LMS->GetInvoiceContent($invoiceid))
+			if (!$LMS->IsInvoicePaid($invoiceid))
 			{
-				$invoice = $LMS->DB->GetRow('SELECT customerid FROM invoices WHERE id=?', array($invoiceid));
-				foreach($invoicecontent['content'] as $idx2 => $row)
+				$custid = $LMS->DB->GetOne('SELECT customerid FROM invoices WHERE id=?', array($invoiceid));
+				$items = $LMS->DB->GetAll('SELECT itemid AS id, taxvalue, userid, comment FROM cash WHERE invoiceid=? GROUP BY itemid, taxvalue, userid, comment ORDER BY itemid', array($invoiceid));
+								
+				foreach($items as $item)
 				{
+					$addbalance['value'] = $LMS->GetItemUnpaidValue($invoiceid, $item['id']);
 					$addbalance['time'] = $invoicepaydate;
 					$addbalance['type'] = 3;
-					$addbalance['value'] = $row['value'] * $row['count'];
-					$addbalance['taxvalue'] = $row['taxvalue'];
-					$addbalance['userid'] = $invoice['customerid'];
-					$addbalance['comment'] = $row['description'];
+					$addbalance['taxvalue'] = $item['taxvalue'];
+					$addbalance['userid'] = $custid;
+					$addbalance['comment'] = $item['comment'];
+					$addbalance['itemid'] = $item['id'];
 					$addbalance['invoiceid'] = $invoiceid;
 					$LMS->AddBalance($addbalance);
 				}
 			}
 	}
 }
-elseif (!$LMS->IsInvoicePaid($invoiceid) && $invoicecontent = $LMS->GetInvoiceContent($invoiceid))
+elseif (!$LMS->IsInvoicePaid($invoiceid))
 {
-	foreach($invoicecontent['content'] as $idx => $row)
+	$custid = $LMS->DB->GetOne('SELECT customerid FROM invoices WHERE id=?', array($invoiceid));
+	$items = $LMS->DB->GetAll('SELECT itemid AS id, taxvalue, userid, comment 
+				FROM cash WHERE invoiceid=? 
+				GROUP BY itemid, taxvalue, userid, comment 
+				ORDER BY itemid', array($invoiceid));
+							
+	foreach($items as $item)
 	{
+		$addbalance['value'] = $LMS->GetItemUnpaidValue($invoiceid, $item['id']);
 		$addbalance['time'] = $invoicepaydate;
 		$addbalance['type'] = 3;
-		$addbalance['value'] = $row['value'] * $row['count'];
-		$addbalance['taxvalue'] = $row['taxvalue'];
-		$addbalance['userid'] = $invoicecontent['customerid'];
-		$addbalance['comment'] = $row['description'];
+		$addbalance['taxvalue'] = $item['taxvalue'];
+		$addbalance['userid'] = $custid;
+		$addbalance['comment'] = $item['comment'];
+		$addbalance['itemid'] = $item['id'];
 		$addbalance['invoiceid'] = $invoiceid;
 		$LMS->AddBalance($addbalance);
 	}
 }
 
-header("Location: ?".$_SESSION['backto']);
+header('Location: ?'.$SESSION->get('backto'));
 
 ?>
