@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: logout.php,v 1.22.2.2 2005/01/01 19:19:55 alec Exp $
+ *  $Id: logout.php,v 1.26.2.1 2005/05/13 20:10:04 alec Exp $
  */
 
 if($_GET['is_sure'] == '1') 
 {
-	$SESSION->LogOut();
+	$AUTH->LogOut();
 	header('Location: ?m=welcome');
 } else
-	header('Location: ?m='.$_SESSION['lastmodule']);    
+	header('Location: ?m='.$SESSION->get('lastmodule'));
 
 ?>
