@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,13 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netadd.php,v 1.33.2.3 2005/01/01 19:19:55 alec Exp $
+ *  $Id: netadd.php,v 1.42.2.2 2005/05/20 11:44:40 kondi Exp $
  */
 
-$netadd = $_POST['netadd'];
-
-if(isset($netadd))
+if(isset($_POST['netadd']))
 {
+	$netadd = $_POST['netadd'];
+	
 	foreach($netadd as $key=>$value)
 	{
 		$netadd[$key] = trim($value);
@@ -48,83 +48,79 @@ if(isset($netadd))
 
 
 	if($netadd['name'] == '')
-		$error['name'] = 'Musisz poda nazw sieci!';
+		$error['name'] = trans('Network name is required!');
 	elseif(!eregi('^[._a-z0-9-]+$', $netadd['name']))
-		$error['name'] = 'Podana nazwa sieci zawiera niepoprawne znaki!';
+		$error['name'] = trans('Network name contains forbidden characters!');
 	
 	if($netadd['domain'] != '' && !eregi('^[.a-z0-9-]+$', $netadd['domain']))
-		$error['domain'] = 'Podana nazwa domeny zawiera niepoprawne znaki!';
+		$error['domain'] = trans('Specified domain contains forbidden characters!');
 	
 	if(!check_ip($netadd['address']))
-		$error['address'] = 'Podany adres IP sieci jest nieprawidowy!';
+		$error['address'] = trans('Incorrect network IP address!');
 	else
 	{
 		if(getnetaddr($netadd['address'], prefix2mask($netadd['prefix'])) != $netadd['address'])
 		{
-			$error['address'] = 'Podany adres nie jest pocztkowym adresem sieci, ustawiam na '.getnetaddr($netadd['address'], prefix2mask($netadd['prefix']));
+			$error['address'] = trans('Specified address is not a network address, setting $0',getnetaddr($netadd['address'], prefix2mask($netadd['prefix'])));
 			$netadd['address'] = getnetaddr($netadd['address'], prefix2mask($netadd['prefix']));
 		}
 		else
 		{
 			if($LMS->NetworkOverlaps($netadd['address'], prefix2mask($netadd['prefix'])))
-				$error['address'] = 'Podany adres sieci pokrywa si z inn sieci!';
+				$error['address'] = trans('Specified IP address overlaps with other network!');
 		}
 	}
 
 	if($netadd['interface'] != '' && !eregi('^[a-z0-9:.]+$', $netadd['interface']))
-		$error['interface'] = 'Niepoprawna nazwa interfejsu!';
+		$error['interface'] = trans('Incorrect interface name!');
 
 	if($netadd['dns'] != '' && !check_ip($netadd['dns']))
-		$error['dns'] = 'Podany adres IP serwera DNS jest nieprawidowy!';
+		$error['dns'] = trans('Incorrect DNS server IP address!');
 	
 	if($netadd['dns2'] != '' && !check_ip($netadd['dns2']))
-		$error['dns2'] = 'Podany adres IP serwera DNS jest nieprawidowy!';
+		$error['dns2'] = trans('Incorrect DNS server IP address!');
 	
 	if($netadd['wins'] != '' && !check_ip($netadd['wins']))
-		$error['wins'] = 'Podany adres IP serwera WINS jest nieprawidowy!';
+		$error['wins'] = trans('Incorrect WINS server IP address!');
 	
 	if($netadd['gateway'] != '')
 		if(!check_ip($netadd['gateway']))
-			$error['gateway'] = 'Podany adres IP bramy jest nieprawidowy!';
+			$error['gateway'] = trans('Incorrect gateway IP address!');
 	elseif(!isipin($netadd['gateway'], getnetaddr($netadd['address'], prefix2mask($netadd['prefix'])), prefix2mask($netadd['prefix'])))
-		$error['gateway'] = 'Podany adres bramy nie pasuje do adresu sieci!';
+		$error['gateway'] = trans('Specified gateway address does not match with network address!');
 	
 	if($netadd['dhcpstart'] != '')
 		if(!check_ip($netadd['dhcpstart']))
-			$error['dhcpstart'] = 'Podany adres IP pocztku zakresu DHCP jest nieprawidowy!';
+			$error['dhcpstart'] = trans('Incorrect IP address for DHCP range start!');
 	elseif(!isipin($netadd['dhcpstart'], getnetaddr($netadd['address'], prefix2mask($netadd['prefix'])), prefix2mask($netadd['prefix'])) && $netadd['address'] != '')
-		$error['dhcpstart'] = 'Podany adres IP pocztku zakresu DHCP nie naley do tej sieci!';
+		$error['dhcpstart'] = trans('IP address for DHCP range start does not match with network address!');
 	
 	if($netadd['dhcpend'] != '')
 		if(!check_ip($netadd['dhcpend']))
-			$error['dhcpend'] = 'Podany adres IP koca zakresu DHCP jest nieprawidowy!';
+			$error['dhcpend'] = trans('Incorrect IP address for DHCP range end!');
 	elseif(!isipin($netadd['dhcpend'], getnetaddr($netadd['address'], prefix2mask($netadd['prefix'])), prefix2mask($netadd['prefix'])) && $netadd['address'] != '')
-		$error['dhcpend'] = 'Podany adres IP koca zakresu DHCP nie naley do tej sieci!';
+		$error['dhcpend'] = trans('IP address for DHCP range end does not match with network address!');
 	
-	if(!$error['dhcpstart'] && !$error['dhcpend'])
+	if(!isset($error['dhcpstart']) && !isset($error['dhcpend']))
 	{
 		if(($netadd['dhcpstart'] != '' && $netadd['dhcpend'] == '') || ($netadd['dhcpstart'] == '' && $netadd['dhcpend'] != ''))
-			$error['dhcp'] = 'Musisz poda obydwa zakresy IP dla DHCP!';
+			$error['dhcp'] = trans('Both IP addresses for DHCP range are required!');
 		if($netadd['dhcpstart'] != '' && $netadd['dhcpend'] != '' && !(ip_long($netadd['dhcpend']) > ip_long($netadd['dhcpstart'])))
-			$error['dhcp'] = 'Koniec zakresu DHCP musi by wikszy ni start!';
+			$error['dhcp'] = trans('End of DHCP range has to be greater than start!');
 	}
 	
 	if(!$error)
 	{
-		header('Location: ?m=netinfo&id='.$LMS->NetworkAdd($netadd));
-		die;
+		$SESSION->redirect('?m=netinfo&id='.$LMS->NetworkAdd($netadd));
 	}
 
+	$SMARTY->assign('error', $error);
+	$SMARTY->assign('netadd', $netadd);
 }
 
-$layout['pagetitle'] = 'Nowa sie';
+$layout['pagetitle'] = trans('New Network');
 
-$prefixlist = $LMS->GetPrefixList();
-$netlist = $LMS->GetNetworkList();
-$SMARTY->assign('error', $error);
-$SMARTY->assign('netadd', $netadd);
-$SMARTY->assign('prefixlist', $prefixlist);
-$SMARTY->assign('netlist', $netlist);
+$SMARTY->assign('prefixlist', $LMS->GetPrefixList());
 $SMARTY->display('netadd.html');
 
 ?>
