@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,13 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netcmp.php,v 1.21.2.2 2005/01/01 19:19:56 alec Exp $
+ *  $Id: netcmp.php,v 1.29.2.2 2005/05/20 11:44:40 kondi Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id']))
 {
-	header("Location: ?m=netlist");
-	die;
+	$SESSION->redirect('?m=netlist');
 }
 
 $network['name'] = $LMS->GetNetworkName($_GET['id']);
@@ -35,15 +34,14 @@ $network['name'] = $LMS->GetNetworkName($_GET['id']);
 if($_GET['is_sure'])
 {
 	$LMS->NetworkCompress($_GET['id']);
-	header("Location: ?m=".$_SESSION['lastmodule']."&id=".$_GET['id']);
-	die;
+	$SESSION->redirect('?m='.$SESSION->get('lastmodule').'&id='.$_GET['id']);
 }else{
-	$layout['pagetitle'] = "Porzdkowanie sieci ".strtoupper($network['name']);
+	$layout['pagetitle'] = trans('Readdressing Network $0', strtoupper($network['name']));
 	$SMARTY->display('header.html');
-	echo "<H1>Porzdkowanie sieci ".strtoupper($network['name'])."</H1>";
-	echo "<p>Czy jeste pewien e chcesz uporzdkowa t sie?</p>";
-	echo "<a href=\"?m=netcmp&id=".$_GET['id']."&is_sure=1\">Tak, jestem pewien</A>";
+	echo '<H1>'.trans('Readdressing network $0', strtoupper($network['name'])).'</H1>';
+	echo '<P>'.trans('Are you sure, you want to reorder that network?').'</P>';
+	echo '<A href="?m=netcmp&id='.$_GET['id'].'&is_sure=1">'.trans('Yes, I am sure.').'</A>';
 	$SMARTY->display('footer.html');
 }
 
-?>
\ No newline at end of file
+?>
