@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,32 +21,31 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevdel.php,v 1.9.2.2 2005/01/01 19:19:56 alec Exp $
+ *  $Id: netdevdel.php,v 1.15.2.2 2005/05/20 11:44:40 kondi Exp $
  */
 
 if(! $LMS->NetDevExists($_GET['id']))
 {
-	header('Location: ?m=netdevlist');
-	die;
+	$SESSION->redirect('?m=netdevlist');
 }		
 
-$layout['pagetitle'] = "Usunicie urzdzenia ID: ".sprintf("%04d",$_GET['id']);
+$layout['pagetitle'] = trans('Deletion of Device with ID: $0',sprintf('%04d',$_GET['id']));
 $SMARTY->assign('netdevid',$_GET['id']);
 
 if($LMS->CountNetDevLinks($_GET['id'])>0)
 {
-	$body = "<H1>".$layout['pagetitle']."</H1>";
-	$body .= "<P>Nie mona usun urzdzenia ktre jest podczone do innych urzdze lub komputerw.</P>";
+	$body = '<H1>'.$layout['pagetitle'].'</H1>';
+	$body .= '<P>'.trans('Device connected to other device or node can\'t be deleted.').'</P>';
 }else{
     if($_GET['is_sure']!=1)
     {
-	    $body = "<H1>".$layout['pagetitle']."</H1>";
-	    $body .= "<P>Czy jeste pewien e chcesz usun urzdzenie?</P>"; 
-	    $body .= "<P><A HREF=\"?m=userdel&id=".$_GET['id']."&is_sure=1\">Tak, jestem pewien.</A></P>";
+	    $body = '<H1>'.$layout['pagetitle'].'</H1>';
+	    $body .= '<P>'.trans('Are you sure, you want to delete that device?').'</P>'; 
+	    $body .= '<P><A HREF="?m=userdel&id='.$_GET['id'].'&is_sure=1">'.trans('Yes, I am sure.').'</A></P>';
     }else{
-	    header("Location: ?m=netdevlist");
-	    $body = "<H1>".$layout['pagetitle']."</H1>";
-	    $body .= "<P>Urzdzenie zostao usunite.</P>";
+	    header('Location: ?m=netdevlist');
+	    $body = '<H1>'.$layout['pagetitle'].'</H1>';
+	    $body .= '<P>'.trans('Device has been deleted.').'</P>';
 	    $LMS->DeleteNetDev($_GET['id']);
     }
 }
