@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,58 +21,64 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevedit.php,v 1.28.2.2 2005/01/01 19:19:57 alec Exp $
+ *  $Id: netdevedit.php,v 1.41.2.2 2005/05/20 11:44:40 kondi Exp $
  */
 
 if(! $LMS->NetDevExists($_GET['id']))
 {
-	header('Location: ?m=netdevlist');
-	die;
+	$SESSION->redirect('?m=netdevlist');
 }		
 
-$edit = data;
+$action = isset($_GET['action']) ? $_GET['action'] : '';
+$edit = 'data';
 
-switch($_GET['action'])
+switch($action)
 {
 case 'replace':
 	$dev1 = $LMS->GetNetDev($_GET['id']);
 	$dev2 = $LMS->GetNetDev($_GET['netdev']);
-	if ($dev1['ports']<$dev2['takenports']) {
-	    $error['replace'] = 'Brak wystarczajcej liczby portw w urzdzeniu rdowym!';
+	if ($dev1['ports'] < $dev2['takenports']) 
+	{
+	    $error['replace'] = trans('It scans for ports in source device!');
 	    $edit = FALSE;
-	} elseif ($dev2['ports']<$dev1['takenports']) {
-	    $error['replace'] = 'Brak wystarczajcej liczby portw w urzdzeniu docelowym!';
+	} 
+	elseif ($dev2['ports'] < $dev1['takenports']) 
+	{
+	    $error['replace'] = trans('It scans for ports in destination device!');
 	    $edit = FALSE;
-	} else {
+	} 
+	else 
+	{
 	    $LMS->NetDevReplace($_GET['id'],$_GET['netdev']);
-	    header('Location: ?m=netdevinfo&id='.$_GET['id']);
-	    die;
+	    $SESSION->redirect('?m=netdevinfo&id='.$_GET['id']);
 	}
 	break;
 	
 case 'disconnect':
 	$LMS->NetDevUnLink($_GET['id'],$_GET['devid']);
-	header('Location: ?m=netdevinfo&id='.$_GET['id']);
-	die;
+	$SESSION->redirect('?m=netdevinfo&id='.$_GET['id']);
 
 case 'disconnectnode':
 	$LMS->NetDevLinkNode($_GET['nodeid'],0);
-	header('Location: ?m=netdevinfo&id='.$_GET['id']);
-	die;
+	$SESSION->redirect('?m=netdevinfo&id='.$_GET['id']);
 
 case 'connect':
-	if(! $LMS->NetDevLink($_GET['netdev'], $_GET['id']) )
+	$linktype = isset($_GET['linktype']) ? $_GET['linktype'] : '0';
+	$SESSION->save('devlinktype', $linktype);
+	if(! $LMS->NetDevLink($_GET['netdev'], $_GET['id'], $linktype) )
 	{
 		$edit = FALSE;
-		$error['link'] = 'Brak wolnych portw w urzdzeniu!';
+		$error['link'] = trans('No free ports on device!');
 	} else
 		header('Location: ?m=netdevinfo&id='.$_GET['id']);
 	break;
     
 case 'connectnode':
-	if(! $LMS->NetDevLinkNode($_GET['nodeid'], $_GET['id']) )
+	$linktype = isset($_GET['linktype']) ? $_GET['linktype'] : '0';
+	$SESSION->save('nodelinktype', $linktype);
+	if(! $LMS->NetDevLinkNode($_GET['nodeid'], $_GET['id'], $linktype) )
 	{
-		$error['linknode'] = 'Brak wolnych portw w urzdzeniu';
+		$error['linknode'] = trans('No free ports on device!');
 		$edit = FALSE;
 	} else
 		header('Location: ?m=netdevinfo&id='.$_GET['id']);
@@ -83,15 +89,25 @@ case 'addip':
 	break;
 
 case 'editip':
-	$nodeipdata=$LMS->GetNode($_GET['ip']);
+	$nodeipdata = $LMS->GetNode($_GET['ip']);
 	$nodeipdata['ipaddr'] = $nodeipdata['ip'];
 	$SMARTY->assign('nodeipdata',$nodeipdata);
 	$edit = 'ip';
 	break;
 
+case 'switchlinktype':
+	$LMS->SetNetDevLinkType($_GET['devid'], $_GET['id'], $_GET['linktype']);
+	header('Location: ?m=netdevinfo&id='.$_GET['id']);
+	break;
+
+case 'switchnodelinktype':
+	$LMS->SetNodeLinkType($_GET['nodeid'], $_GET['linktype']);
+	header('Location: ?m=netdevinfo&id='.$_GET['id']);
+	break;
+
 case 'formaddip':
 	$nodeipdata = $_POST['ipadd'];
-	$nodeipdata['ownerid']=0;
+	$nodeipdata['ownerid'] = 0;
 	
 	$nodeipdata['mac'] = str_replace('-',':',$nodeipdata['mac']);
 	foreach($nodeipdata as $key => $value)
@@ -99,43 +115,43 @@ case 'formaddip':
 	
 	if($nodeipdata['ipaddr']=='' && $nodeipdata['mac']=='' && $nodeipdata['name']=='')
 	{
-		header('Location: ?m=netdevedit&action=addip&id='.$_GET['id']);
-		die;
+		$SESSION->redirect('?m=netdevedit&action=addip&id='.$_GET['id']);
         }
 	
 	if($nodeipdata['name']=='')
-		$error['ipname'] = 'Prosz poda nazw dla adresu!';
+		$error['ipname'] = trans('Address field is required!');
 	elseif(strlen($nodeipdata['name']) > 16)
-		$error['ipname'] = 'Podana nazwa jest za duga!';
+		$error['ipname'] = trans('Specified name is too long (max.$0 characters)!','16');
 	elseif($LMS->GetNodeIDByName($nodeipdata['name']))
-		$error['ipname'] = 'Podana nazwa jest uywana!';
-	elseif(!eregi("^[_a-z0-9-]+$",$nodeipdata['name']))
-		$error['ipname'] = 'Podana nazwa zawiera niepoprawne znaki!';		
+		$error['ipname'] = trans('Specified name is in use!');
+	elseif(!eregi('^[_a-z0-9-]+$',$nodeipdata['name']))
+		$error['ipname'] = trans('Name contains forbidden characters!');
 
 	if($nodeipdata['ipaddr']=='')
-		$error['ipaddr'] = 'Prosz podac adres IP!';
+		$error['ipaddr'] = trans('IP address is required!');
 	elseif(!check_ip($nodeipdata['ipaddr']))
-		$error['ipaddr'] = 'Podany adres IP jest niepoprawny!';
+		$error['ipaddr'] = trans('Incorrect IP address!');
 	elseif(!$LMS->IsIPValid($nodeipdata['ipaddr']))
-		$error['ipaddr'] = 'Podany adres IP nie naley do adnej sieci!';
+		$error['ipaddr'] = trans('Specified address does not belongs to any network!');
 	elseif(!$LMS->IsIPFree($nodeipdata['ipaddr']))
-		$error['ipaddr'] = 'Podany adres IP jest zajty!';
+		$error['ipaddr'] = trans('IP address is in use!');
 
 	if($nodeipdata['mac']=='')
-		$error['mac'] = 'Prosz podac adres MAC!';
+		$error['mac'] = trans('MAC address is required!');
 	elseif(!check_mac($nodeipdata['mac']))
-		$error['mac'] = 'Podany adres MAC jest nieprawidowy!';
+		$error['mac'] = trans('Incorrect MAC address!');
 	elseif($LMS->CONFIG['phpui']['allow_mac_sharing'] == FALSE)
 		if($LMS->GetNodeIDByMAC($nodeipdata['mac']))
-			$error['mac'] = 'Podany MAC jest ju w bazie!';
+			$error['mac'] = trans('MAC address is in use!');
 
-	
 	if(!$error)
 	{
+		$nodeipdata['ipaddr_pub'] = '0.0.0.0';
 		$nodeipdata['warning'] = 0;
-		$LMS->NetDevLinkNode($LMS->NodeAdd($nodeipdata),$_GET['id']);
-		header('Location: ?m=netdevinfo&id='.$_GET['id']);
-		die;
+		$nodeipdata['passwd'] = '';
+		$nodeipdata['netdev'] = $_GET['id'];
+		$LMS->NodeAdd($nodeipdata);
+		$SESSION->redirect('?m=netdevinfo&id='.$_GET['id']);
 	}
 	$SMARTY->assign('nodeipdata',$nodeipdata); 
 	$edit='addip';
@@ -152,73 +168,74 @@ case 'formeditip':
 	
 	if($nodeipdata['ipaddr']=='' && $nodeipdata['mac']=='' && $nodeipdata['name']=='')
 	{
-		header('Location: ?m=netdevedit&action=editip&id='.$_GET['id'].'&ip='.$_GET['ip']);
-		die;
+		$SESSION->redirect('?m=netdevedit&action=editip&id='.$_GET['id'].'&ip='.$_GET['ip']);
         }
 	
 	if($nodeipdata['name']=='')
-		$error['ipname'] = 'Prosz poda nazw dla adresu!';
+		$error['ipname'] = trans('Address field is required!');
 	elseif(strlen($nodeipdata['name']) > 16)
-		$error['ipname'] = 'Podana nazwa jest za duga!';
+		$error['ipname'] = trans('Specified name is too long (max.$0 characters)!','16');
 	elseif(
 		$LMS->GetNodeIDByName($nodeipdata['name']) &&
 		$LMS->GetNodeName($_GET['ip'])!=$nodeipdata['name']
 		)
-		$error['ipname'] = 'Podana nazwa jest uywana!';
-	elseif(!eregi("^[_a-z0-9-]+$",$nodeipdata['name']))
-		$error['ipname'] = 'Podana nazwa zawiera niepoprawne znaki!';		
+		$error['ipname'] = trans('Specified name is in use!');
+	elseif(!eregi('^[_a-z0-9-]+$',$nodeipdata['name']))
+		$error['ipname'] = trans('Name contains forbidden characters!');	
 
 	if($nodeipdata['ipaddr']=='')
-		$error['ipaddr'] = 'Prosz podac adres IP!';
+		$error['ipaddr'] = trans('IP address is required!');
 	elseif(!check_ip($nodeipdata['ipaddr']))
-		$error['ipaddr'] = 'Podany adres IP jest niepoprawny!';
+		$error['ipaddr'] = trans('Incorrect IP address!');
 	elseif(!$LMS->IsIPValid($nodeipdata['ipaddr']))
-		$error['ipaddr'] = 'Podany adres IP nie naley do adnej sieci!';
+		$error['ipaddr'] =  trans('Specified address does not belongs to any network!');
 	elseif(
 		!$LMS->IsIPFree($nodeipdata['ipaddr']) &&
 		$LMS->GetNodeIPByID($_GET['ip'])!=$nodeipdata['ipaddr']
 		)
-		$error['ipaddr'] = 'Podany adres IP jest zajty!';
+		$error['ipaddr'] = trans('IP address is in use!');
 	
 	if($nodeipdata['mac']=='')
-		$error['mac'] = 'Prosz podac adres MAC!';
+		$error['mac'] =  trans('MAC address is required!');
 	elseif(!check_mac($nodeipdata['mac']))
-		$error['mac'] = 'Podany adres MAC jest nieprawidowy!';
-	elseif($LMS->CONFIG['phpui']['allow_mac_sharing'] == FALSE)
+		$error['mac'] = trans('Incorrect MAC address!');
+	elseif(isset($LMS->CONFIG['phpui']['allow_mac_sharing']) &&
+		$LMS->CONFIG['phpui']['allow_mac_sharing'] == FALSE
+		)
 		if($LMS->GetNodeIDByMAC($nodeipdata['mac']) && $LMS->GetNodeMACByID($_GET['ip'])!=$nodeipdata['mac'])
-			$error['mac'] = 'Podany MAC jest ju w bazie!';
+			$error['mac'] = trans('MAC address is in use!');
 	
 	$nodeipdata['warning'] = 0;
+	$nodeipdata['passwd'] = '';
 
 	if(!$error)
 	{
+		$nodeipdata['ipaddr_pub'] = '0.0.0.0';
 		$LMS->NodeUpdate($nodeipdata);	
-		header('Location: ?m=netdevinfo&id='.$_GET['id']);
-		die;
+		$SESSION->redirect('?m=netdevinfo&id='.$_GET['id']);
 	}
 	$SMARTY->assign('nodeipdata',$nodeipdata); 
 	$edit='ip';
 	break;
 }
 
-$netdevdata = $_POST['netdev'];
-if(isset($netdevdata))
+if(isset($_POST['netdev']))
 {
+	$netdevdata = $_POST['netdev'];
 	$netdevdata['id'] = $_GET['id'];
 
 	if($netdevdata['name'] == '')
-		$error['name'] = 'Pole nazwa nie moe by puste!';
+		$error['name'] = trans('Device name is required!');
 	elseif(strlen($netdevdata['name']) > 32)
-		$error['name'] = 'Podana nazwa jest za duga!';
+		$error['name'] =  trans('Specified name is too long (max.$0 characters)!','32');
 
 	if($netdevdata['ports'] < $LMS->CountNetDevLinks($_GET['id']))
-		$error['ports'] = 'Liczba podczonych urzdze przekracza liczb portw!';
+		$error['ports'] = trans('Connected devices number exceeds number of ports!');
 	
 	if(!$error)
 	{
 		$LMS->NetDevUpdate($netdevdata);
-		header('Location: ?m=netdevinfo&id='.$_GET['id']);
-		die;
+		$SESSION->redirect('?m=netdevinfo&id='.$_GET['id']);
 	}
 }
 else
@@ -227,7 +244,7 @@ else
 $netdevdata['id'] = $_GET['id'];
 
 $netdevconnected = $LMS->GetNetDevConnectedNames($_GET['id']);
-$netcomplist = $LMS->GetNetdevLinkedNodes($_GET['id']);
+$netcomplist = $LMS->GetNetDevLinkedNodes($_GET['id']);
 $netdevlist = $LMS->GetNotConnectedDevices($_GET['id']);
 
 unset($netdevlist['total']);
@@ -249,7 +266,7 @@ unset($replacelist['direction']);
 
 $netdevips = $LMS->GetNetDevIPs($_GET['id']);
 
-$layout['pagetitle'] = 'Edycja urzdzenia: '.$netdevdata['name'].' '.$netdevdata['producer'];
+$layout['pagetitle'] = trans('Device Edit: $0 ($1)', $netdevdata['name'], $netdevdata['producer']);
 
 $SMARTY->assign('error',$error);
 $SMARTY->assign('netdevinfo',$netdevdata);
@@ -260,6 +277,8 @@ $SMARTY->assign('netdevips',$netdevips);
 $SMARTY->assign('restnetdevlist',$netdevlist);
 $SMARTY->assign('replacelist',$replacelist);
 $SMARTY->assign('replacelisttotal',$replacelisttotal);
+$SMARTY->assign('devlinktype',$SESSION->get('devlinktype'));
+$SMARTY->assign('nodelinktype',$SESSION->get('nodelinktype'));
 
 switch($edit)
 {
@@ -277,4 +296,3 @@ switch($edit)
     break;
 }
 ?>
-
