@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,13 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevinfo.php,v 1.15.2.2 2005/01/01 19:19:57 alec Exp $
+ *  $Id: netdevinfo.php,v 1.24.2.1 2005/05/13 20:10:04 alec Exp $
  */
 
 if(! $LMS->NetDevExists($_GET['id']))
 {
-	header('Location: ?m=netdevlist');
-	die;
+	$SESSION->redirect('?m=netdevlist');
 }
 
 $netdevinfo = $LMS->GetNetDev($_GET['id']);
@@ -51,9 +50,9 @@ unset($nodelist['totalon']);
 unset($nodelist['totaloff']);
 unset($nodelist['direction']);
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
-$layout['pagetitle'] = "Informacje o urzdzeniu: ".$netdevinfo['name']." ".$netdevinfo['producer']." ".$netdevinfo['model'];
+$layout['pagetitle'] = trans('Device Info: $0 $1 $2', $netdevinfo['name'], $netdevinfo['producer'], $netdevinfo['model']);
 
 $netdevinfo['id'] = $_GET['id'];
 
@@ -65,7 +64,10 @@ $SMARTY->assign('netdevips',$netdevips);
 $SMARTY->assign('nodelist',$nodelist);
 $SMARTY->assign('replacelist',$replacelist);
 $SMARTY->assign('replacelisttotal',$replacelisttotal);
-$SMARTY->assign('nodeipdata',$LMS->GetNode($_GET['ip']));
+$SMARTY->assign('devlinktype',$SESSION->get('devlinktype'));
+$SMARTY->assign('nodelinktype',$SESSION->get('nodelinktype'));
+if(isset($_GET['ip']))
+	$SMARTY->assign('nodeipdata',$LMS->GetNode($_GET['ip']));
 $SMARTY->display('netdevinfo.html');
 
 ?>
