@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,25 +21,26 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netinfo.php,v 1.27.2.3 2005/01/01 19:19:59 alec Exp $
+ *  $Id: netinfo.php,v 1.34.2.1 2005/05/13 20:10:04 alec Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id']))
 {
-	header("Location: ?m=netlist");
-	die;
+	$SESSION->redirect('?m=netlist');
 }
 
-if (isset($_SESSION['ntlp'][$_GET['id']]) && !isset($_GET['page']))
-	$_GET['page'] = $_SESSION['ntlp'][$_GET['id']];
+$page = isset($_GET['page']) ? $_GET['page'] : 1;
 
-$_SESSION['ntlp'][$_GET['id']] = $_GET['page'];
+if($SESSION->is_set('ntlp.'.$_GET['id']) && !isset($_GET['page']))
+	$SESSION->restore('ntlp.'.$_GET['id'], $page);
 
-$network = $LMS->GetNetworkRecord($_GET['id'],$_GET['page'], $LMS->CONFIG['phpui']['networkhosts_pagelimit']);
+$SESSION->save('ntlp.'.$_GET['id'], $page);
 
-$layout['pagetitle'] = "Informacja o sieci: ".$network['name'];
+$network = $LMS->GetNetworkRecord($_GET['id'], $page, $LMS->CONFIG['phpui']['networkhosts_pagelimit']);
 
-$SMARTY->assign('network',$network);
+$layout['pagetitle'] = trans('Info Network: $0', $network['name']);
+
+$SMARTY->assign('network', $network);
 $SMARTY->display('netinfo.html');
 
 ?>
