@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,22 +21,23 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netlist.php,v 1.25.2.2 2005/01/01 19:19:59 alec Exp $
+ *  $Id: netlist.php,v 1.31.2.1 2005/05/13 20:10:04 alec Exp $
  */
 
-$layout['pagetitle'] = "Sieci IP";
+$layout['pagetitle'] = trans('IP Networks');
 
 $netlist = $LMS->GetNetworkList();
 
 $listdata['size'] = $netlist['size'];
 $listdata['assigned'] = $netlist['assigned'];
+$listdata['online'] = $netlist['online'];
 
-unset($netlist['assigned'], $netlist['size'], $netlist['total']);
-
+unset($netlist['assigned']);
+unset($netlist['size']);
+unset($netlist['online']);
 $listdata['total'] = sizeof($netlist);
 
 $SMARTY->assign('listdata',$listdata);
-$SMARTY->assign('netadd',$netadd);
 $SMARTY->assign('netlist',$netlist);
 $SMARTY->display('netlist.html');
 
