@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeedit.php,v 1.54.2.6 2005/01/13 08:42:26 alec Exp $
+ *  $Id: nodeedit.php,v 1.74.2.2 2005/05/20 11:44:41 kondi Exp $
  */
 
 if(!$LMS->NodeExists($_GET['id']))
@@ -30,50 +30,50 @@ if(!$LMS->NodeExists($_GET['id']))
 	else
 		header('Location: ?m=nodelist');
 
-if($_GET['action']=='link')
+$action = isset($_GET['action']) ? $_GET['action'] : '';
+
+if($action=='link')
 {
 	$netdev = $LMS->GetNetDev($_GET['devid']); 
 
 	if($netdev['ports'] > $netdev['takenports']) 
 	{
 		$LMS->NetDevLinkNode($_GET['id'],$_GET['devid']);
-		header('Location: ?m=nodeinfo&id='.$_GET['id']);
-		die;
+		$SESSION->redirect('?m=nodeinfo&id='.$_GET['id']);
 	}
 	else
 	{
-		header('Location: ?m=nodeinfo&id='.$_GET['id'].'&devid='.$_GET['devid']);
-		die;
+		$SESSION->redirect('?m=nodeinfo&id='.$_GET['id'].'&devid='.$_GET['devid']);
 	}	
 }
 
 $nodeid = $_GET['id'];
 $ownerid = $LMS->GetNodeOwner($nodeid);
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 	
 if(!isset($_GET['ownerid']))
-	$_SESSION['backto'] .= '&ownerid='.$ownerid;
+	$SESSION->save('backto', $SESSION->get('backto') . '&ownerid='.$ownerid);
 							
-$owner = $ownerid;
-$userinfo=$LMS->GetUser($owner);
-$layout['pagetitle'] = 'Informacje o uytkowniku: '.$userinfo['username'].' - edycja komputera: '.$LMS->GetNodeName($_GET['id']);
+$userinfo = $LMS->GetUser($ownerid);
+$layout['pagetitle'] = trans('Customer Info: $0 - Node Edit: $1',$userinfo['username'], $LMS->GetNodeName($_GET['id']));
 
-$nodeedit = $_POST['nodeedit'];
-$usernodes = $LMS->GetUserNodes($owner);
+$usernodes = $LMS->GetUserNodes($ownerid);
 $nodeinfo = $LMS->GetNode($_GET['id']);
 
-if(isset($nodeedit))
+if(isset($_POST['nodeedit']))
 {
+	$nodeedit = $_POST['nodeedit'];
+	
 	$nodeedit['ipaddr'] = $_POST['nodeeditipaddr'];
+	$nodeedit['ipaddr_pub'] = $_POST['nodeeditipaddrpub'];
 	$nodeedit['mac'] = $_POST['nodeeditmac'];
 	$nodeedit['mac'] = str_replace('-',':',$nodeedit['mac']);
 	foreach($nodeedit as $key => $value)
 		$nodeedit[$key] = trim($value);
 	
-	if($nodeedit['ipaddr']=='' && $nodeedit['mac']=='' && $nodeedit['name']=='')
+	if($nodeedit['ipaddr']=='' && $nodeedit['ipaddr_pub']=='' && $nodeedit['mac']=='' && $nodeedit['name']=='' && $nodeedit['info']=='' && $nodeedit['passwd']=='')
 	{
-		header('Location: ?m=nodeinfo&id='.$nodeedit['id']);
-		die;
+		$SESSION->redirect('?m=nodeinfo&id='.$nodeedit['id']);
 	}
 
 	if(check_ip($nodeedit['ipaddr']))
@@ -82,50 +82,78 @@ if(isset($nodeedit))
 		{
 			$ip = $LMS->GetNodeIPByID($nodeedit['id']);
 			if($ip!=$nodeedit['ipaddr'] && !$LMS->IsIPFree($nodeedit['ipaddr']))
-				$error['ipaddr'] = 'Podany adres IP jest zajty!';
+				$error['ipaddr'] = trans('Specified IP address is in use!');
 			elseif($ip!=$nodeedit['ipaddr'] && $LMS->IsIPGateway($nodeedit['ipaddr']))
-				$error['ipaddr'] = 'Podany adres IP jest adresem bramy!';
+				$error['ipaddr'] = trans('Specified IP address is network gateway!');
 		}
 		else
-			$error['ipaddr'] = 'Podany adres IP nie naley do adnej sieci!';
+			$error['ipaddr'] = trans('Specified IP address doesn\'t overlap with any network!');
 	}
 	else
-		$error['ipaddr'] = 'Podany adres IP jest niepoprawny!';
+		$error['ipaddr'] = trans('Incorrect IP address!');
+
+	if($nodeedit['ipaddr_pub']!='0.0.0.0' && $nodeedit['ipaddr_pub']!='')
+	{
+		if(check_ip($nodeedit['ipaddr_pub']))
+        	{
+        	        if($LMS->IsIPValid($nodeedit['ipaddr_pub']))
+        	        {
+        	                $ip = $LMS->GetNodePubIPByID($nodeedit['id']);
+        	                if($ip!=$nodeedit['ipaddr_pub'] && !$LMS->IsIPFree($nodeedit['ipaddr_pub']))
+        	                        $error['ipaddr_pub'] = trans('Specified IP address is in use!');
+        	                elseif($ip!=$nodeedit['ipaddr_pub'] && $LMS->IsIPGateway($nodeedit['ipaddr_pub']))
+        	                        $error['ipaddr_pub'] = trans('Specified IP address is network gateway!');
+        	        }
+        	        else
+        	                $error['ipaddr_pub'] = trans('Specified IP address doesn\'t overlap with any network!');
+        	}
+        	else
+        	        $error['ipaddr_pub'] = trans('Incorrect IP address!');
+	}
+	else
+		$nodeedit['ipaddr_pub'] = '0.0.0.0';
 
 	if(check_mac($nodeedit['mac']))
 	{
-		if($LMS->CONFIG['phpui']['allow_mac_sharing'] == FALSE)
+		if(isset($LMS->CONFIG['phpui']['allow_mac_sharing']) && 
+			$LMS->CONFIG['phpui']['allow_mac_sharing'] == FALSE
+			)
 			if($LMS->GetNodeIDByMAC($nodeedit['mac']) && $LMS->GetNodeMACByID($nodeedit['id'])!=$nodeedit['mac'])
-				$error['mac'] = 'Podany adres MAC jest ju przypisany do innego komputera!';
+				$error['mac'] = trans('Specified MAC address is in use!');
 	}
 	else
-		$error['mac'] = 'Podany adres MAC jest bdny!';
+		$error['mac'] = trans('Incorrect MAC address!');
 
 	if($nodeedit['name']=='')
-		$error['name'] = 'Podaj nazw!';
+		$error['name'] = trans('Node name is required!');
 	elseif($LMS->GetNodeIDByName($nodeedit['name']) && $LMS->GetNodeIDByName($nodeedit['name']) != $nodeedit['id'])
-		$error['name'] = 'Ta nazwa jest zajta!';
-	elseif(!eregi("^[_a-z0-9-]+$",$nodeedit['name']))
-		$error['name'] = 'Podana nazwa zawiera niepoprawne znaki!';
+		$error['name'] = trans('Specified name is in use!');
+	elseif(!eregi('^[_a-z0-9-]+$',$nodeedit['name']))
+		$error['name'] = trans('Specified name contains forbidden characters!');
 	elseif(strlen($nodeedit['name'])>16)
-		$error['name'] = 'Podana nazwa jest za duga!';
+		$error['name'] = trans('Node name is too long (max.16 characters)!');
+
+	if(strlen($nodeedit['passwd'])>32)
+		$error['passwd'] = trans('Password is too long (max.32 characters)!');
 
 	if($nodeedit['access']!=1)
 		$nodeedit['access'] = 0;
-        if($nodeedit['warning'] != 1)
+        if($nodeedit['warning']!=1)
                 $nodeedit['warning'] = 0;	
 
 	if($nodeinfo['netdev'] != $nodeedit['netdev'] && $nodeedit['netdev'] != 0)
 	{
 		$netdev = $LMS->GetNetDev($nodeedit['netdev']); 
 		if($netdev['ports'] <= $netdev['takenports'])
-		    $error['netdev'] = 'Brak wolnych portw w wybranym urzdzeniu!';
+		    $error['netdev'] = trans('It scans for free ports in selected device!');
 		$nodeinfo['netdev'] = $nodeedit['netdev'];
 	}
 	
 	$nodeinfo['name'] = $nodeedit['name'];
 	$nodeinfo['mac'] = $nodeedit['mac'];
 	$nodeinfo['ip'] = $nodeedit['ipaddr'];
+	$nodeinfo['ip_pub'] = $nodeedit['ipaddr_pub'];
+	$nodeinfo['passwd'] = $nodeedit['passwd'];
 	$nodeinfo['access'] = $nodeedit['access'];
 	$nodeinfo['ownerid'] = $nodeedit['ownerid'];
 
@@ -134,20 +162,20 @@ if(isset($nodeedit))
 		$LMS->NodeUpdate($nodeedit);
 		header('Location: ?m=nodeinfo&id='.$nodeedit['id']);
 	}
+
+	if($nodeedit['ipaddr_pub']=='0.0.0.0')
+		$nodeinfo['ipaddr_pub'] = '';
 }
 
 if($userinfo['status']==3) $userinfo['shownodes'] = TRUE;
 $users = $LMS->GetUserNames();
 $tariffs = $LMS->GetTariffs();
 $assignments = $LMS->GetUserAssignments($ownerid);
-$balancelist = $LMS->GetUserBalanceList($owner);
+$balancelist = $LMS->GetUserBalanceList($ownerid);
 $usergroups = $LMS->UsergroupGetForUser($ownerid);
 $otherusergroups = $LMS->GetGroupNamesWithoutUser($ownerid);
-
-$netdevices = $LMS->GetNetDevList();
-unset($netdevices['total']);
-unset($netdevices['direction']);
-unset($netdevices['order']);
+$contractlist = $LMS->GetContractList();
+$netdevices = $LMS->GetNetDevNames();
 
 $SMARTY->assign('netdevices',$netdevices);
 $SMARTY->assign('balancelist',$balancelist);
@@ -159,8 +187,8 @@ $SMARTY->assign('error',$error);
 $SMARTY->assign('userinfo',$userinfo);
 $SMARTY->assign('nodeinfo',$nodeinfo);
 $SMARTY->assign('users',$users);
+$SMARTY->assign('contractlist',$contractlist);
+$SMARTY->assign('contractcount',sizeof($contractlist));
 $SMARTY->display('nodeedit.html');
 
 ?>
-
-
