@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,21 +21,28 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodescan.php,v 1.15.2.2 2005/01/01 19:20:01 alec Exp $
+ *  $Id: nodescan.php,v 1.20.2.1 2005/05/13 20:10:05 alec Exp $
  */
 
-if($_GET['ownerid']&&$LMS->UserExists($_GET['ownerid']))
+if($_GET['ownerid'] && $LMS->UserExists($_GET['ownerid']))
 {
-	$userinfo = $LMS->GetUser($_GET['ownerid']);
+	$contractlist = $LMS->GetContractList();
+
+	$SMARTY->assign('assignments', $LMS->GetUserAssignments($_GET['ownerid']));
+	$SMARTY->assign('usergroups', $LMS->UsergroupGetForUser($_GET['ownerid']));
+	$SMARTY->assign('otherusergroups', $LMS->GetGroupNamesWithoutUser($_GET['ownerid']));
+	$SMARTY->assign('tariffs', $LMS->GetTariffs());
+	$SMARTY->assign('userinfo', $LMS->GetUser($_GET['ownerid']));
+	$SMARTY->assign('balancelist', $LMS->GetUserBalanceList($_GET['ownerid']));
+	$SMARTY->assign('contractlist',$contractlist);
+	$SMARTY->assign('contractcount',sizeof($contractlist));
 }
 
-$layout['pagetitle'] = "Wyszukiwanie komputerw";
+$layout['pagetitle'] = trans('Nodes Scanning');
+
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
-$SMARTY->assign('balancelist',$LMS->GetUserBalanceList($_GET['ownerid']));
-$SMARTY->assign('users',$users);
 $SMARTY->assign('nodes',$LMS->ScanNodes());
-$SMARTY->assign('userinfo',$userinfo);
-
 $SMARTY->display('nodescan.html');
 
-?>
\ No newline at end of file
+?>
