@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,30 +21,35 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodesearch.php,v 1.22.2.2 2005/01/01 19:20:01 alec Exp $
+ *  $Id: nodesearch.php,v 1.30.2.3 2005/05/23 12:20:30 alec Exp $
  */
 
-$layout['pagetitle'] = "Wyszukiwanie komputerw";
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+if(isset($_POST['search']))
+	$nodesearch = $_POST['search'];
 
-$search = $_POST['search'];
-
-if(!isset($search))
-	$search = $_SESSION['usersearch'];
+if(!isset($nodesearch))
+	$SESSION->restore('nodesearch', $nodesearch);
 else
-	$_SESSION['usersearch'] = $search;		
+	$SESSION->save('nodesearch', $nodesearch);
+if(!isset($_GET['o']))
+	$SESSION->restore('nslo', $o);
+else
+	$o = $_GET['o'];
+$SESSION->save('nslo', $o);
 
-if($_GET['search']==1 || isset($_GET['search'])) 
+if(!isset($_POST['k']))
+	$SESSION->restore('nslk', $k);
+else
+	$k = $_POST['k'];
+$SESSION->save('nslk', $k);
+
+if(isset($_GET['search'])) 
 {
-	if(!isset($_GET['o']))
-		$o = $_SESSION['snlo'];
-	else
-		$o = $_GET['o'];
+	$layout['pagetitle'] = trans('Nodes Search Results');
 
-	$_SESSION['snlo'] = $o;
-			
-	$nodelist = $LMS->SearchNodeList($search,$o);
+	$nodelist = $LMS->GetNodeList($o, $nodesearch, $k);
 
 	$listdata['total'] = $nodelist['total'];
 	$listdata['order'] = $nodelist['order'];
@@ -58,26 +63,36 @@ if($_GET['search']==1 || isset($_GET['search']))
 	unset($nodelist['totalon']);
 	unset($nodelist['totaloff']);
 	
-	if (isset($_SESSION['nslp']) && !isset($_GET['page']))
-		$_GET['page'] = $_SESSION['nslp'];
+	if ($SESSION->is_set('nslp') && !isset($_GET['page']))
+		$SESSION->restore('nslp', $_GET['page']);
 		
-	$page = (! $_GET['page'] ? 1 : $_GET['page']);
+	$page = (!isset($_GET['page']) ? 1 : $_GET['page']);
 	
 	$pagelimit = (! $LMS->CONFIG['phpui']['nodelist_pagelimit'] ? $listdata['total'] : $LMS->CONFIG['phpui']['nodelist_pagelimit']);
 	$start = ($page - 1) * $pagelimit;
-	$_SESSION['nslp'] = $page;
+	$SESSION->save('nslp', $page);
 	
 	$SMARTY->assign('page',$page);
 	$SMARTY->assign('pagelimit',$pagelimit);
 	$SMARTY->assign('start',$start);
 	$SMARTY->assign('nodelist',$nodelist);
 	$SMARTY->assign('listdata',$listdata);
-	$SMARTY->display('nodesearchresults.html');
 	
+	if(isset($_GET['print']))
+		$SMARTY->display('printnodelist.html');
+	elseif($listdata['total']==1)
+		$SESSION->redirect('?m=nodeinfo&id='.$nodelist[0]['id']);
+	else
+		$SMARTY->display('nodesearchresults.html');
 }
-else 
+else
 {
+	$layout['pagetitle'] = trans('Nodes Search');
+
+	$SESSION->remove('nslp');
+	
+	$SMARTY->assign('k',$k);
 	$SMARTY->display('nodesearch.html');
 }
 
-?>
\ No newline at end of file
+?>
