@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,19 +21,28 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeset.php,v 1.18.2.2 2005/01/01 19:20:02 alec Exp $
+ *  $Id: nodeset.php,v 1.24.2.1 2005/05/13 20:10:05 alec Exp $
  */
 
-if($LMS->UserExists($_GET['ownerid']))
+$ownerid = isset($_GET['ownerid']) ? $_GET['ownerid'] : 0;
+$id = isset($_GET['id']) ? $_GET['id'] : 0;
+
+if($LMS->UserExists($ownerid))
 {
-	$LMS->NodeSetU($_GET['ownerid'], $_GET['access']);
-	$backid = $_GET['ownerid'];
+	$LMS->NodeSetU($ownerid, $_GET['access']);
+
+	$backid = $ownerid;
+	$redir = $SESSION->get('backto');
+	if($SESSION->get('lastmodule')=='usersearch')
+		$redir .= '&search=1';
+
+	$SESSION->redirect('?'.$redir.'#'.$backid);
 }
 
-if($LMS->NodeExists($_GET['id']))
+if($LMS->NodeExists($id))
 {
-	$LMS->NodeSet($_GET['id']);
-	$backid = $_GET['id'];
+	$LMS->NodeSet($id);
+	$backid = $id;
 }
 
 if(isset($_GET['netdev']))
@@ -43,6 +52,6 @@ if(isset($_GET['netdev']))
 		$backid = $_GET['netdev'];
 	}
 
-header("Location: ?".$_SESSION['backto']."#".$backid);
+header('Location: ?'.$SESSION->get('backto').'#'.$backid);
 
 ?>
