@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,57 +21,67 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodewarn.php,v 1.6.2.2 2005/01/01 19:20:02 alec Exp $
+ *  $Id: nodewarn.php,v 1.16.2.1 2005/05/13 20:10:05 alec Exp $
  */
 
-$setwarnings = $_POST['setwarnings'];
+$setwarnings = isset($_POST['setwarnings']) ? $_POST['setwarnings'] : array();
 
-if(sizeof($setwarnings['mnodeid']))
+if(isset($setwarnings['mnodeid']))
 {
+	$message = isset($setwarnings['message']) ? $setwarnings['message'] : '';
+	$warnon = isset($setwarnings['warnon']) ? $setwarnings['warnon'] : FALSE;
+	$warnoff = isset($setwarnings['warnoff']) ? $setwarnings['warnoff'] : FALSE;
+
 	foreach($setwarnings['mnodeid'] as $value)
 	{
-		if($setwarnings['warnon'])
+		if($warnon)
 			$LMS->NodeSetWarn($value, TRUE);
-		if($setwarnings['warnoff']) 
+		if($warnoff) 
 			$LMS->NodeSetWarn($value, FALSE);
 		
-		if (isset($setwarnings['message']))
+		if($message)
 		{
 			$LMS->SetTS('users');
-			$LMS->DB->Execute('UPDATE users SET message=? WHERE id=?', array($setwarnings['message'],$LMS->GetNodeOwner($value)));
+			$LMS->DB->Execute('UPDATE users SET message=? WHERE id=?', array($message,$LMS->GetNodeOwner($value)));
 		}
 	}
-	$_SESSION['warnmessage'] = $setwarnings['message'];
-	$_SESSION['warnon'] = $setwarnings['warnon'];
-	$_SESSION['warnoff'] = $setwarnings['warnoff'];
+	$SESSION->save('warnmessage', $message);
+	$SESSION->save('warnon', $warnon);
+	$SESSION->save('warnoff', $warnoff);
 	
-	header('Location: ?'.$_SESSION['backto']);
-	die;
+	$SESSION->redirect('?'.$SESSION->get('backto'));
 }
 
-if($backid = $_GET['ownerid'])
+$backid = isset($_GET['ownerid']) ? $_GET['ownerid'] : 0;
+
+if($backid)
 {
 	if($LMS->UserExists($backid))
 	{
 		$LMS->NodeSetWarnU($backid, $_GET['warning']);
-		header('Location: ?'.$_SESSION['backto'].'#'.$backid);
-		die;
+		
+		$redir = $SESSION->get('backto');
+		if($SESSION->get('lastmodule')=='usersearch')
+			$redir .= '&search=1';
+			
+		$SESSION->redirect('?'.$redir.'#'.$backid);
 	}
 }
 
-if($backid = $_GET['id'])
+$backid = isset($_GET['id']) ? $_GET['id'] : 0;
+
+if($backid)
 {
 	if($LMS->NodeExists($backid))
 	{
 		$LMS->NodeSwitchWarn($backid);
-		header('Location: ?'.$_SESSION['backto'].'#'.$backid);
-		die;
+		$SESSION->redirect('?'.$SESSION->get('backto').'#'.$backid);
 	}
 }
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
-$layout['pagetitle'] = 'Ostrzeenia';
+$layout['pagetitle'] = trans('Messages');
 
 $nodelist = $LMS->GetNodeList();
 unset($nodelist['total']);
@@ -80,11 +90,10 @@ unset($nodelist['direction']);
 unset($nodelist['totalon']);
 unset($nodelist['totaloff']);
 
-$SMARTY->assign('warnmessage', $_SESSION['warnmessage']);
-$SMARTY->assign('warnon', $_SESSION['warnon']);
-$SMARTY->assign('warnoff', $_SESSION['warnoff']);
+$SMARTY->assign('warnmessage', $SESSION->get('warnmessage'));
+$SMARTY->assign('warnon', $SESSION->get('warnon'));
+$SMARTY->assign('warnoff', $SESSION->get('warnoff'));
 $SMARTY->assign('nodelist',$nodelist);
 $SMARTY->display('nodewarnings.html');
 
 ?>
-
