@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentadd.php,v 1.5.2.2 2005/01/01 19:20:02 alec Exp $
+ *  $Id: paymentadd.php,v 1.10.2.1 2005/05/13 20:10:05 alec Exp $
  */
 
 $payment = $_POST['payment'];
@@ -31,25 +31,23 @@ if(isset($payment))
 	foreach($payment as $key => $value)
 		$payment[$key] = trim($value);
 
-	if($payment['creditor']=="" && $payment['name']=="" && $payment['value']=="")
+	if($payment['creditor']=='' && $payment['name']=='' && $payment['value']=='')
 	{
-		header("Location: ?m=paymentlist");
-		die;
+		$SESSION->redirect('?m=paymentlist');
 	}
 
-	$payment['value'] = str_replace(",",".",$payment['value']);
+	$payment['value'] = str_replace(',','.',$payment['value']);
 
-	if(!(ereg("^[-]?[0-9.,]+$",$payment['value'])))
-		$error['value'] = "Podana warto nie jest poprawna!";
+	if(!(ereg('^[-]?[0-9.,]+$',$payment['value'])))
+		$error['value'] = trans('Incorrect value!');
 
-	if($payment['creditor'] == "")
-		$error['creditor'] = "Musisz poda nazw wierzyciela!";
+	if($payment['creditor'] == '')
+		$error['creditor'] = trans('Creditor name is required!');
 
-	if($payment['name'] == "")
-		$error['name'] = "Musisz poda nazw opaty staej!";
-	else
-		if($LMS->GetPaymentIDByName($payment['name']))
-			$error['name'] = "Istnieje ju opata o nazwie '".$payment['name']."'!";
+	if($payment['name'] == '')
+		$error['name'] = trans('Payment name is required!');
+	elseif($LMS->GetPaymentIDByName($payment['name']))
+		$error['name'] = trans('Specified name is in use!');
 
 	$period = sprintf('%d',$payment['period']);
 	
@@ -61,7 +59,7 @@ if(isset($payment))
 		case 0:
 			$at = sprintf('%d',$payment['at']);
 			if($at < 1 || $at > 7)
-				$error['at'] = 'Niepoprawny dzie tygodnia';
+				$error['at'] = trans('Incorrect day of week (1-7)!');
 		break;
 		case 1:
 			$at = sprintf('%d',$payment['at']);
@@ -72,29 +70,28 @@ if(isset($payment))
 					$at = 1;
 			}
 			if($at < 1 || $at > 28)
-		    		$error['at'] = 'Niepoprawny dzie miesica';
+		    		$error['at'] = trans('Incorrect day of month (1-28)!');
 		break;
 		case 2:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
-				$error['at'] = 'Niepoprawny format daty';
+				$error['at'] = trans('Incorrect date format!');
 			else {
 				list($d,$m) = split('/',trim($payment['at']));
 				if($d>30 || $d<1)
-					$error['at'] = 'Niepoprawna liczba dni w miesicu';
+					$error['at'] = trans('Incorrect day of month (1-30)!');
 				if($m>3 || $m<1)
-					$error['at'] = 'Niepoprawny numer miesica (max.3)';
+					$error['at'] = trans('Incorrect month number (max.3)!');
 				
 				$at = ($m-1) * 100 + $d;
 			};
 		break;
 		case 3:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
-				$error['at'] = 'Niepoprawny format daty';
+				$error['at'] = trans('Incorrect date format!');
 			else
 				list($d,$m) = split('/',trim($payment['at']));
 			$ttime = mktime(12, 0, 0, $m, $d, 1990);
 			$at = date('z',$ttime) + 1;
-			
 		break;	
 	}
 	
@@ -105,8 +102,7 @@ if(isset($payment))
 		$payment['at'] = $at;
 		if($payment['reuse'] =='')
 		{
-			header("Location: ?m=paymentlist&id=".$LMS->PaymentAdd($payment));
-			die;
+			$SESSION->redirect('?m=paymentlist&id='.$LMS->PaymentAdd($payment));
 		} else
 			$LMS->PaymentAdd($payment);
 			
@@ -115,7 +111,7 @@ if(isset($payment))
 	}
 }
 
-$layout['pagetitle'] = "Nowa opata staa";
+$layout['pagetitle'] = trans('New Payment');
 
 $SMARTY->assign('error',$error);
 $SMARTY->assign('payment',$payment);
