@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,13 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentdel.php,v 1.2.2.3 2005/01/01 19:20:02 alec Exp $
+ *  $Id: paymentdel.php,v 1.6.2.1 2005/05/13 20:10:05 alec Exp $
  */
 
 if($_GET['is_sure']=='1')
 	$LMS->PaymentDelete($_GET['id']);	
 
-header('Location: ?m=paymentlist');
-die;
+$SESSION->redirect('?m=paymentlist');
 
 ?>
\ No newline at end of file
