@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,20 +21,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentinfo.php,v 1.5.2.2 2005/01/01 19:20:03 alec Exp $
+ *  $Id: paymentinfo.php,v 1.11.2.1 2005/05/13 20:10:06 alec Exp $
  */
 
 if(!$LMS->PaymentExists($_GET['id']))
 {
-	header("Location: ?m=paymentlist");
-	die;
+	$SESSION->redirect('?m=paymentlist');
 }
 
 $payment = $LMS->GetPayment($_GET['id']);
 
-$layout['pagetitle'] = "Informacja o opacie staej: ".$payment['name'];
+$layout['pagetitle'] = trans('Payment Info: $0',$payment['name']);
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('payment',$payment);
 $SMARTY->display('paymentinfo.html');
