@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentlist.php,v 1.5.2.2 2005/01/01 19:20:03 alec Exp $
+ *  $Id: paymentlist.php,v 1.9.2.1 2005/05/13 20:10:06 alec Exp $
  */
 
-$layout['pagetitle'] = "Lista opat staych";
+$layout['pagetitle'] = trans('Payments List');
 
 $paymentlist = $LMS->GetPaymentList();
 
@@ -32,7 +32,7 @@ $listdata['total'] = $paymentlist['total'];
 
 unset($paymentlist['total']);
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('paymentlist',$paymentlist);
 $SMARTY->assign('listdata',$listdata);
