@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,11 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtmessageview.php,v 1.6.2.3 2005/01/01 19:20:04 alec Exp $
+ *  $Id: rtmessageview.php,v 1.15.2.1 2005/05/13 20:10:06 alec Exp $
  */
 
-if($filename = $_GET['file'])
+if(isset($_GET['file']))
 {
+	$filename = $_GET['file'];
 	if($attach = $LMS->GetAttachment($_GET['mid'], $filename))
 	{
 		$file = $LMS->CONFIG['rt']['mail_dir'].sprintf("/%06d/%06d/%s",$_GET['tid'],$_GET['mid'],$filename);
@@ -38,14 +39,14 @@ if($filename = $_GET['file'])
 			header('Content-Disposition: attachment; filename='.$filename);
 			@readfile($file);
 		}
+		$SESSION->close();
 		die;
 	}
 }
 
-if(! $_GET['id'])
+if(!isset($_GET['id']))
 {
-	header('Location: ?'.$_SESSION['backto']);
-	die;
+	$SESSION->redirect('?'.$SESSION->get('backto'));
 }
 
 
@@ -74,9 +75,9 @@ if(!$message['userid'] && !$message['adminid'] && !$message['mailfrom'])
 	$message['requestor'] = $LMS->DB->GetOne('SELECT requestor FROM rttickets WHERE id=?', array($message['ticketid']));
 }
 
-$layout['pagetitle'] = 'Podgld wiadomoci';
+$layout['pagetitle'] = trans('Ticket Review');
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('message', $message);
 $SMARTY->display('rtmessageview.html');
