@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueueadd.php,v 1.7.2.3 2005/01/01 19:20:04 alec Exp $
+ *  $Id: rtqueueadd.php,v 1.15.2.2 2005/05/20 11:44:42 kondi Exp $
  */
 
 $queue = $_POST['queue'];
@@ -30,18 +30,17 @@ if(isset($queue))
 {
 	if($queue['name']=='' && $queue['email']=='' && $queue['description']=='')
 	{
-		header('Location: ?m=rtqueuelist');
-		die;
+		$SESSION->redirect('?m=rtqueuelist');
 	}
 
 	if($queue['name'] == '')
-		$error['name'] = 'Kolejka musi posiada nazw!';
+		$error['name'] = trans('Queue name must be defined!');
 
 	if($queue['name'] != '' && $LMS->GetQueueIdByName($queue['name']))
-		$error['name'] = 'Kolejka o podanej nazwie jest ju w bazie!';
+		$error['name'] = trans('Queue with specified name already exists!');
 
 	if($queue['email']!='' && !check_email($queue['email']))
-		$error['email'] = 'Podany email nie wydaje si by poprawny!';
+		$error['email'] = trans('Incorrect email!');
 
 	if(isset($queue['admins']))
 		foreach($queue['admins'] as $key => $value)
@@ -50,8 +49,7 @@ if(isset($queue))
 	if(!$error)
 	{
 		$id = $LMS->QueueAdd($queue);
-		header("Location: ?m=rtqueueinfo&id=".$id);
-		die;
+		$SESSION->redirect('?m=rtqueueinfo&id='.$id);
 	}
 }
 
@@ -64,9 +62,9 @@ foreach($admins as $admin)
 }
 $queue['rights'] = $queue['nrights'];
 
-$layout['pagetitle'] = 'Nowa kolejka';
+$layout['pagetitle'] = trans('New Queue');
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('queue', $queue);
 $SMARTY->assign('error', $error);
