@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,13 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueueedit.php,v 1.1.2.2 2005/01/01 19:20:04 alec Exp $
+ *  $Id: rtqueueedit.php,v 1.6.2.2 2005/05/20 11:44:42 kondi Exp $
  */
 
 if(! $LMS->QueueExists($_GET['id']))
 {
-	header('Location: ?m=rtqueuelist');
-	die;
+	$SESSION->redirect('?m=rtqueuelist');
 }
 
 $queue = $_POST['queue'];
@@ -37,10 +36,10 @@ if(isset($queue))
 	$queue['id'] = $_GET['id'];
 	
 	if($queue['name'] == '')
-		$error['name'] = "Kolejka musi posiada nazw!";
+		$error['name'] = trans('Queue name must be defined!');
 
 	if($queue['email']!='' && !check_email($queue['email']))
-		$error['email'] = 'Podany email nie wydaje si by poprawny!';
+		$error['email'] = trans('Incorrect email!');
 
 	if(isset($queue['admins']))
 		foreach($queue['admins'] as $key => $value)
@@ -49,16 +48,15 @@ if(isset($queue))
 	if(!$error)
 	{
 		$LMS->QueueUpdate($queue);
-		header("Location: ?m=rtqueueinfo&id=".$queue['id']);
-		die;
+		$SESSION->redirect('?m=rtqueueinfo&id='.$queue['id']);
 	}
 }
 else
 	$queue = $LMS->GetQueue($_GET['id']);
 
-$layout['pagetitle'] = 'Edycja kolejki: '.$queue['name'];
+$layout['pagetitle'] = trans('Queue Edit: $0',$queue['name']);
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('queue', $queue);
 $SMARTY->assign('error', $error);
