@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,20 +21,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueueinfo.php,v 1.1.2.2 2005/01/01 19:20:04 alec Exp $
+ *  $Id: rtqueueinfo.php,v 1.7.2.1 2005/05/13 20:10:06 alec Exp $
  */
 
 if(! $LMS->QueueExists($_GET['id']))
 {
-	header('Location: ?m=rtqueuelist');
-	die;
+	$SESSION->redirect('?m=rtqueuelist');
 }
 
 $queue = $LMS->GetQueue($_GET['id']);
 
-$layout['pagetitle'] = 'Informacje o kolejce: '.$queue['name'];
+$layout['pagetitle'] = trans('Queue Info: $0',$queue['name']);
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('queue', $queue);
 $SMARTY->display('rtqueueinfo.html');
