@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueuelist.php,v 1.3.2.2 2005/01/01 19:20:04 alec Exp $
+ *  $Id: rtqueuelist.php,v 1.8.2.1 2005/05/13 20:10:06 alec Exp $
  */
 
-$layout['pagetitle'] = 'Obsuga zgosze';
+$layout['pagetitle'] = trans('Queues List');
 
 $queues = $LMS->GetQueueList();
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('queues', $queues);
 $SMARTY->display('rtqueuelist.html');
