@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,47 +21,52 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueueview.php,v 1.9.2.2 2005/01/01 19:20:05 alec Exp $
+ *  $Id: rtqueueview.php,v 1.19.2.1 2005/05/13 20:10:06 alec Exp $
  */
 
 if(! $LMS->QueueExists($_GET['id']))
 {
-	header('Location: ?m=rtqueuelist');
-	die;
+	$SESSION->redirect('?m=rtqueuelist');
 }
 
 $queuedata['id'] = $_GET['id'];
 
-if(! $LMS->GetAdminRightsRT($SESSION->id, $queuedata['id']))
+if(! $LMS->GetAdminRightsRT($AUTH->id, $queuedata['id']))
 {
 	$SMARTY->display('noaccess.html');
+	$SESSION->close();
 	die;
 }
 
+if(isset($_GET['delticketid']))
+{
+	$LMS->TicketDelete($_GET['delticketid']);
+}
+
 if(!isset($_GET['o']))
-	$o = $_SESSION['rto'];
+	$SESSION->restore('rto', $o);
 else
 	$o = $_GET['o'];
-$_SESSION['rto'] = $o;
+$SESSION->save('rto', $o);
 
 if(!isset($_GET['s']))
-	$s = $_SESSION['rts'];
+	$SESSION->restore('rts', $s);
 else
 	$s = $_GET['s'];
-$_SESSION['rts'] = $s;
+$SESSION->save('rts', $s);
 
 $queuedata['name'] = $LMS->GetQueueName($queuedata['id']);
 
-$layout['pagetitle'] = 'Podgld kolejki: '.$queuedata['name'];
+$layout['pagetitle'] = trans('Queue Review: $0',$queuedata['name']);
 $queue = $LMS->GetQueueContents($_GET['id'], $o, $s);
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
-if (isset($_SESSION['rtp']) && !isset($_GET['page']))
-	$_GET['page'] = $_SESSION['rtp'];
+if ($SESSION->is_set('rtp') && !isset($_GET['page']))
+	$SESSION->restore('rtp', $_GET['page']);
 
 $queuedata['total'] = $queue['total'];
-$queuedata['state'] = $_SESSION['rts'];;
+$queuedata['state'] = $queue['state'];
 $queuedata['order'] = $queue['order'];
 $queuedata['direction'] = $queue['direction'];
 unset($queue['total']);
@@ -69,11 +74,11 @@ unset($queue['state']);
 unset($queue['order']);
 unset($queue['direction']);
 
-$page = (! $_GET['page'] ? 1 : $_GET['page']); 
-$pagelimit = (! $LMS->CONFIG['phpui']['ticketlist_pagelimit'] ? $queuedata['total'] : $LMS->CONFIG['phpui']['ticketlist_pagelimit']);
+$page = (!isset($_GET['page']) ? 1 : $_GET['page']); 
+$pagelimit = (!isset($LMS->CONFIG['phpui']['ticketlist_pagelimit']) ? $queuedata['total'] : $LMS->CONFIG['phpui']['ticketlist_pagelimit']);
 $start = ($page - 1) * $pagelimit;
 
-$_SESSION['rtp'] = $page;
+$SESSION->save('rtp', $page);
 
 $SMARTY->assign('queue', $queue);
 $SMARTY->assign('queuedata', $queuedata);
