@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,24 +21,24 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtticketedit.php,v 1.4.2.3 2005/01/01 19:20:06 alec Exp $
+ *  $Id: rtticketedit.php,v 1.13.2.2 2005/05/20 11:44:42 kondi Exp $
  */
 
 $ticketedit = $_POST['ticket'];
 
 if(($id = $_GET['id']) && !isset($ticketedit))
 {
-	if($LMS->GetAdminRightsRT($SESSION->id, 0, $id) < 2)
+	if($LMS->GetAdminRightsRT($AUTH->id, 0, $id) < 2)
 	{
 		$SMARTY->display('noaccess.html');
+		$SESSION->close();
 		die;
 	}
 
 	if($_GET['state'])
 	{
 		$LMS->SetTicketState($id, $_GET['state']);
-		header('Location: ?m=rtticketview&id='.$id);
-		die;
+		$SESSION->redirect('?m=rtticketview&id='.$id);
 	}
 }
 
@@ -47,14 +47,14 @@ $ticket = $LMS->GetTicketContents($id);
 if(isset($ticketedit))
 {
 	$ticketedit['ticketid'] = $ticket['ticketid'];
-	if($LMS->GetAdminRightsRT($SESSION->id, $ticketedit['queueid']) < 2)
-		$error['queue'] = "Nie masz uprawnie do tej kolejki!";
+	if($LMS->GetAdminRightsRT($AUTH->id, $ticketedit['queueid']) < 2)
+		$error['queue'] = trans('You have no privileges to this queue!');
 	
 	if($ticketedit['subject'] == '')
-		$error['subject'] = "Zgoszenie musi posiada tytu!";
+		$error['subject'] = trans('Ticket must have its title!');
 
 	if($ticketedit['state']>0 && !$ticketedit['owner'])
-		$error['owner'] = 'Tylko \'nowe\' zgoszenie moe nie mie waciciela!';
+		$error['owner'] = trans('Only \'new\' ticket can be owned by no one!');
 
 	if($ticketedit['state']==0 && $ticketedit['owner'])
 		$ticketedit['state'] = 1;
@@ -63,8 +63,7 @@ if(isset($ticketedit))
 	if(!$error)
 	{
 		$LMS->TicketUpdate($ticketedit);
-		header("Location: ?m=rtticketview&id=".$id);
-		die;
+		$SESSION->redirect('?m=rtticketview&id='.$id);
 	}
 	
 	$ticket['subject'] = $ticketedit['subject'];
@@ -73,9 +72,9 @@ if(isset($ticketedit))
 	$ticket['owner'] = $ticketedit['owner'];
 }
 
-$layout['pagetitle'] = 'Edycja zgoszenia Nr '.sprintf("%06d",$ticket['ticketid']);
+$layout['pagetitle'] = trans('Ticket Edit: No. $0',sprintf("%06d",$ticket['ticketid']));
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('ticket', $ticket);
 $SMARTY->assign('queuelist', $LMS->GetQueueNames());
