@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,26 +21,26 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtticketprint.php,v 1.1.2.2 2005/01/01 19:20:06 alec Exp $
+ *  $Id: rtticketprint.php,v 1.7.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
 if(! $LMS->TicketExists($_GET['id']))
 {
-	header('Location: ?m=rtqueuelist');
-	die;
+	$SESSION->redirect('?m=rtqueuelist');
 }
 
-if(! $LMS->GetAdminRightsRT($SESSION->id, 0, $_GET['id']))
+if(! $LMS->GetAdminRightsRT($AUTH->id, 0, $_GET['id']))
 {
 	$SMARTY->display('noaccess.html');
+	$SESSION->close();
 	die;
 }
 
 $ticket = $LMS->GetTicketContents($_GET['id']);
 
-$layout['pagetitle'] = 'Zgoszenie Nr '.sprintf("%06d",$ticket['ticketid']);
+$layout['pagetitle'] = trans('Ticket No $0',sprintf("%06d",$ticket['ticketid']));
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('ticket', $ticket);
 $SMARTY->display('rtticketprint.html');
