@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffadd.php,v 1.37.2.2 2005/01/01 19:20:06 alec Exp $
+ *  $Id: tariffadd.php,v 1.42.2.2 2005/05/20 11:44:42 kondi Exp $
  */
 
 $tariffadd = $_POST['tariffadd'];
@@ -33,18 +33,17 @@ if(isset($tariffadd))
 
 	if($tariffadd['name']=='' && $tariffadd['comment']=='' && $tariffadd['value']=='')
 	{
-		header("Location: ?m=tarifflist");
-		die;
+		$SESSION->redirect('Location: ?m=tarifflist');
 	}
 
 	$tariffadd['value'] = str_replace(',','.',$tariffadd['value']);
 
 	if(!(ereg('^[-]?[0-9.,]+$',$tariffadd['value'])))
-		$error['value'] = 'Podana warto taryfy jest niepoprawna!';
+		$error['value'] = trans('Incorrect subscription value!');
 
 	if($tariffadd['taxvalue']!='')
 		if(!(ereg('^[0-9.,]+$',$tariffadd['taxvalue'])) || $tariffadd['taxvalue'] < 0 || $tariffadd['taxvalue'] > 100)
-			$error['taxvalue'] = 'Podana stawka podatku jest niepoprawna!';
+			$error['taxvalue'] = trans('Incorrect tax rate!');
 
 	if($tariffadd['uprate']=='') $tariffadd['uprate'] = 0;
 	if($tariffadd['downrate']=='') $tariffadd['downrate'] = 0;
@@ -54,42 +53,41 @@ if(isset($tariffadd))
 	if($tariffadd['plimit']=='') $tariffadd['plimit'] = 0;
 
 	if(!ereg('^[0-9]+$', $tariffadd['uprate']))
-		$error['uprate'] = 'To pole musi zawiera liczb cakowit';
+		$error['uprate'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariffadd['downrate']))
-		$error['downrate'] = 'To pole musi zawiera liczb cakowit';
+		$error['downrate'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariffadd['upceil']))
-		$error['upceil'] = 'To pole musi zawiera liczb cakowit';
+		$error['upceil'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariffadd['downceil']))
-		$error['downceil'] = 'To pole musi zawiera liczb cakowit';
+		$error['downceil'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariffadd['climit']))
-		$error['climit'] = 'To pole musi zawiera liczb cakowit';
+		$error['climit'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariffadd['plimit']))
-		$error['plimit'] = 'To pole musi zawiera liczb cakowit';
+		$error['plimit'] = trans('Integer value expected!');
 
 	if(($tariffadd['uprate'] < 8 || $tariffadd['uprate'] > 4096) && $tariffadd['uprate'] != 0)
-		$error['uprate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
+		$error['uprate'] = trans('This field must be within range 8 - 4096');
 	if(($tariffadd['downrate'] < 8 || $tariffadd['downrate'] > 4096) && $tariffadd['downrate'] != 0)
-		$error['downrate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
+		$error['downrate'] = trans('This field must be within range 8 - 4096');
 	if(($tariffadd['upceil'] < 8 || $tariffadd['upceil'] < $tariffadd['uprate']) && $tariffadd['upceil'] != 0)
-		$error['upceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od upload rate';
+		$error['upceil'] = trans('This field must contain number greater than 8 and greater than upload rate');
 	if(($tariffadd['downceil'] < 8 || $tariffadd['downceil'] < $tariffadd['downrate']) && $tariffadd['downceil'] != 0)
-		$error['downceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od download rate';
+		$error['downceil'] = trans('This field must contain number greater than 8 and greater than download rate');
 
 	if($tariffadd['name'] == '')
-		$error['name'] = 'Musisz poda nazw taryfy!';
+		$error['name'] = trans('Subscription name required!');
 	else
 		if($LMS->GetTariffIDByName($tariffadd['name']))
-			$error['name'] = "Istnieje ju taryfa o nazwie '".$tariffadd['name']."'!";
+			$error['name'] = trans('Subscription $0 already exists!',$tariffadd['name']);
 
 	if(!$error)
 	{
-		header('Location: ?m=tarifflist&id='.$LMS->TariffAdd($tariffadd));
-		die;
+		$SESSION->redirect('?m=tarifflist&id='.$LMS->TariffAdd($tariffadd));
 	}
 	
 }
 
-$layout['pagetitle'] = 'Nowa taryfa';
+$layout['pagetitle'] = trans('New Subscription');
 
 $SMARTY->assign('error',$error);
 $SMARTY->assign('tariffadd',$tariffadd);
