@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,13 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffdelete.php,v 1.19.2.2 2005/01/01 19:20:06 alec Exp $
+ *  $Id: tariffdelete.php,v 1.22.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
 if(!$LMS->GetUsersWithTariff($_GET['id'])&&$_GET['is_sure']="1")
 	$LMS->TariffDelete($_GET['id']);	
 
-header("Location: ?m=tarifflist");
-die;
+$SESSION->redirect('?m=tarifflist');
 
 ?>
\ No newline at end of file
