@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,13 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffedit.php,v 1.25.2.2 2005/01/01 19:20:06 alec Exp $
+ *  $Id: tariffedit.php,v 1.30.2.2 2005/05/20 11:44:42 kondi Exp $
  */
 
 if(!$LMS->TariffExists($_GET['id']))
 {
-	header('Location: ?m=tarifflist');
-	die;
+	$SESSION->redirect('?m=tarifflist');
 }
 
 $tariff = $_POST['tariff'];
@@ -47,40 +46,40 @@ if(isset($tariff))
 	if($tariff['plimit'] == '') $tariff['plimit'] = 0;
 
 	if($tariff['name'] == '')
-		$error['name'] = 'Prosz poda nazw taryfy!';
+		$error['name'] = trans('Subscription name required!');
 	elseif($LMS->GetTariffIDByName($tariff['name']) && $tariff['name'] != $LMS->GetTariffName($_GET['id']))
-		$error['name'] = 'Istnieje ju taryfa o takiej nazwie!';	
+		$error['name'] = trans('Subscription with specified name already exists!');
 
 	if($tariff['value'] == '')
-		$error['value'] = 'Prosz poda warto!';
+		$error['value'] = trans('Value required!');
 	elseif(!(ereg('^[-]?[0-9.,]+$', $tariff['value'])))
-		$error['value'] = 'Podana warto jest niepoprawna!';
+		$error['value'] = trans('Incorrect value!');
 	
 	if($tariff['taxvalue'] != '')
 	  	if(!(ereg('^[0-9.,]+$', $tariff['taxvalue'])) || $tariff['taxvalue'] < 0 || $tariff['taxvalue'] > 100)
-			$error['taxvalue'] = 'Podana stawka podatku jest niepoprawna!';
+			$error['taxvalue'] = trans('Incorrect tax rate!');
 
 	if(!(ereg("^[0-9]+$", $tariff['uprate'])))
-		$error['uprate'] = 'To pole musi zawiera liczb cakowit';
+		$error['uprate'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariff['downrate']))
-		$error['downrate'] = 'To pole musi zawiera liczb cakowit';
+		$error['downrate'] = trans('Integer value expected!');
 	if(!(ereg("^[0-9]+$", $tariff['upceil'])))
-		$error['upceil'] = 'To pole musi zawiera liczb cakowit';
+		$error['upceil'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariff['downceil']))
-		$error['downceil'] = 'To pole musi zawiera liczb cakowit';
+		$error['downceil'] = trans('Integer value expected!');
 	if(!(ereg("^[0-9]+$", $tariff['climit'])))
-		$error['climit'] = 'To pole musi zawiera liczb cakowit';
+		$error['climit'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariff['plimit']))
-		$error['plimit'] = 'To pole musi zawiera liczb cakowit';
+		$error['plimit'] = trans('Integer value expected!');
 	
 	if(($tariff['uprate'] < 8 || $tariff['uprate'] > 4096) && $tariff['uprate'] != 0)
-		$error['uprate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
+		$error['uprate'] = trans('This field must be within range 8 - 4096');
 	if(($tariff['downrate'] < 8 || $tariff['downrate'] > 4096) && $tariff['downrate'] != 0)
-		$error['downrate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
+		$error['downrate'] = trans('This field must be within range 8 - 4096');
 	if(($tariff['upceil'] < 8 || $tariff['upceil'] < $tariff['uprate']) && $tariff['upceil'] != 0)
-		$error['upceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od upload rate';
+		$error['upceil'] = trans('This field must be greater than 8 and greater than upload rate');
 	if(($tariff['downceil'] < 8 || $tariff['downceil'] < $tariff['downrate']) && $tariff['downceil'] != 0)
-		$error['downceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od download rate';
+		$error['downceil'] = trans('This field must be greater than 8 and greater than download rate');
 
 
 	$tariff['id'] = $_GET['id'];
@@ -88,14 +87,13 @@ if(isset($tariff))
 	if(!$error)
 	{
 		$LMS->TariffUpdate($tariff);
-		header('Location: ?m=tariffinfo&id='.$tariff['id']);
-		die;
+		$SESSION->redirect('?m=tariffinfo&id='.$tariff['id']);
 	}
 
 }else
 	$tariff = $LMS->GetTariff($_GET['id']);
 	
-$layout['pagetitle'] = 'Edycja taryfy: '.$tariff['name'];	
+$layout['pagetitle'] = trans('Subscription Edit: $0',$tariff['name']);
 $SMARTY->assign('tariff',$tariff);
 $SMARTY->assign('error',$error);
 $SMARTY->display('tariffedit.html');
