@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,18 +21,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffinfo.php,v 1.21.2.2 2005/01/01 19:20:06 alec Exp $
+ *  $Id: tariffinfo.php,v 1.27.2.2 2005/05/20 11:44:43 kondi Exp $
  */
 
 if(!$LMS->TariffExists($_GET['id']))
 {
-	header("Location: ?m=tarifflist");
-	die;
+	$SESSION->redirect('?m=tarifflist');
 }
-$tariff = $LMS->GetTariff($_GET['id']);
-$layout['pagetitle'] = "Informacja o taryfie: ".$tariff['name'];
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$tariff = $LMS->GetTariff($_GET['id']);
+
+$layout['pagetitle'] = trans('Subscription Info: $0',$tariff['name']);
+
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('tariff',$tariff);
 $SMARTY->assign('tariffs',$LMS->GetTariffs());
