@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tarifflist.php,v 1.24.2.2 2005/01/01 19:20:06 alec Exp $
+ *  $Id: tarifflist.php,v 1.27.2.2 2005/05/20 11:44:43 kondi Exp $
  */
 
-$layout['pagetitle'] = "Lista taryf";
+$layout['pagetitle'] = trans('Subscription List');
 
 $tarifflist = $LMS->GetTariffList();
 
