@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,16 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffmove.php,v 1.16.2.2 2005/01/01 19:20:06 alec Exp $
+ *  $Id: tariffmove.php,v 1.20.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
 if($LMS->TariffExists($_GET['from']) && $LMS->TariffExists($_GET['to']) && $_GET['is_sure'] = 1)
 {
 	$LMS->TariffMove($_GET['from'],$_GET['to']);
-	header("Location: ?m=tariffinfo&id=".$_GET['to']);
-	die;
+	$SESSION->redirect('?m=tariffinfo&id='.$_GET['to']);
 }
 else
-	header("Location: ?".$_SESSION['backto']);
+	header("Location: ?".$SESSION->get('backto'));
 
-?>
\ No newline at end of file
+?>
