@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,13 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: template.php,v 1.20.2.2 2005/01/01 19:20:07 alec Exp $
+ *  $Id: template.php,v 1.23.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
-$layout['pagetitle'] = "Tytu moduu";
+$layout['pagetitle'] = trans('Module Title');
+
 $SMARTY->display('header.html');
 
-// Tutaj odpowiednie dziaania
+// module body
 
 $SMARTY->display('footer.html');
 
