@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,39 +21,36 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: useradd.php,v 1.50.2.4 2005/01/01 19:20:08 alec Exp $
+ *  $Id: useradd.php,v 1.65.2.2 2005/05/20 11:44:43 kondi Exp $
  */
 
-$useradd = $_POST['useradd'];
-
-if(sizeof($useradd))
-	foreach($useradd as $key=>$value)
-		$useradd[$key] = trim($value);
-
-if($useradd['name']=='' && $useradd['lastname']=='' && $useradd[phone1]=='' && $useradd['address']=='' && $useradd['email']=='' && isset($useradd))
+if(isset($_POST['useradd']))
 {
-	header('Location: ?m=useradd');
-	die;
-}
-elseif(isset($useradd))
-{
-	if($useradd['lastname']=='')
-		$error['username']='Pola \'nazwisko/nazwa\' oraz \'imi\' nie mog by puste!';
-	
-	if($useradd['address']=='')
-		$error['address']='Prosz poda adres!';
-	
-	if($useradd['nip'] !='' && !check_nip($useradd['nip']))
-		$error['nip'] = 'Podany NIP jest bdny!';
+	$useradd = $_POST['useradd'];
 
-	if($useradd['pesel'] != '' && !check_pesel($useradd['pesel']))
-		$error['pesel'] = 'Podany PESEL jest bdny!';
+	if(sizeof($useradd))
+		foreach($useradd as $key=>$value)
+			$useradd[$key] = trim($value);
+
+	if($useradd['name'] == '' && $useradd['lastname'] == '' && $useradd['phone1'] == '' && $useradd['address'] == '' && $useradd['email'] == '')
+	{
+		$SESSION->redirect('?m=useradd');
+	}
+
+	if($useradd['lastname'] == '')
+		$error['username'] = trans('\'Last/Company Name\' and \'First Name\' fields cannot be empty!');
+	
+	if($useradd['address'] == '')
+		$error['address'] = trans('Address required!');
+	
+	if($useradd['nip'] !='' && !check_ten($useradd['nip']))
+		$error['nip'] = trans('Incorrect Tax Exempt Number!');
+
+	if($useradd['pesel'] != '' && !check_ssn($useradd['pesel']))
+		$error['pesel'] = trans('Incorrect Social Security Number!');
 		
-	if($useradd['zip'] !='' && !eregi('^[0-9]{2}-[0-9]{3}$',$useradd['zip']))
-		$error['zip'] = 'Podany kod pocztowy jest bdny!';
-
-	if($useradd['email']!='' && !check_email($useradd['email']))
-		$error['email'] = 'Podany email nie wydaje si by poprawny!';
+	if($useradd['zip'] !='' && !check_zip($useradd['zip']))
+		$error['zip'] = trans('Incorrect ZIP code!');
 
 	if($useradd['gguin'] == '')
 		$useradd['gguin'] = 0;
@@ -62,18 +59,20 @@ elseif(isset($useradd))
 		$useradd['pin'] = 0;
 
 	if($useradd['gguin'] !=0 && !eregi('^[0-9]{4,}$',$useradd['gguin']))
-		$error['gguin'] = 'Podany numer GG jest niepoprawny!';
+		$error['gguin'] = trans('Incorrect IM uin!');
 
         if($useradd['pin']!=0 && !eregi('^[0-9]{4,6}$',$useradd['pin']))
-	        $error['pin'] = 'Podany numer PIN jest niepoprawny!';
-	
+	        $error['pin'] = trans('Incorrect PIN code!');
+
+	if($useradd['email']!='' && !check_email($useradd['email']))
+		$error['email'] = trans('Incorrect email!');
+
 	if(!$error)
 	{
 		$id = $LMS->UserAdd($useradd);
-		if($useradd['reuse'] =='')
+		if(!isset($useradd['reuse']))
 		{
-			header('Location: ?m=userinfo&id='.$id);
-			die;
+			$SESSION->redirect('?m=userinfo&id='.$id);
 		}
 		$reuse['status'] = $useradd['status'];
 		unset($useradd);
@@ -82,14 +81,14 @@ elseif(isset($useradd))
 	}
 }
 
-if(!isset($useradd['zip']))	
+if(!isset($useradd['zip']) && isset($LMS->CONFIG['phpui']['default_zip']))
 	$useradd['zip'] = $LMS->CONFIG['phpui']['default_zip'];
-if(!isset($useradd['city']))	
+if(!isset($useradd['city']) && isset($LMS->CONFIG['phpui']['default_city']))
 	$useradd['city'] = $LMS->CONFIG['phpui']['default_city'];
-if(!isset($useradd['address']))	
+if(!isset($useradd['address']) && isset($LMS->CONFIG['phpui']['default_address']))
 	$useradd['address'] = $LMS->CONFIG['phpui']['default_address'];
 
-$layout['pagetitle'] = 'Nowy uytkownik';
+$layout['pagetitle'] = trans('New Customer');
 
 $SMARTY->assign('useradd',$useradd);
 $SMARTY->assign('error',$error);
