@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,40 +21,38 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userassignments.php,v 1.5.2.5 2005/03/02 14:09:28 alec Exp $
+ *  $Id: userassignments.php,v 1.23.2.2 2005/05/20 11:44:43 kondi Exp $
  */
 
 if(! $LMS->UserExists($_GET['id']))
 {
-	header('Location: ?m=userlist');
-	die;
+	$SESSION->redirect('?m=userlist');
 }
 
 if($_GET['action'] == 'delete')
 {
 	$LMS->DeleteAssignment($_GET['aid'],$_GET['balance']);
-	header('Location: ?m=userinfo&id='.$_GET['id']);
-	die;
+	$SESSION->redirect('?'.$SESSION->get('backto'));
 }
 
 if($_GET['action'] == 'suspend')
 {
 	$LMS->SuspendAssignment($_GET['aid'], $_GET['suspend']);
-	header('Location: ?m=userinfo&id='.$_GET['id']);
-	die;
+	$SESSION->redirect('?'.$SESSION->get('backto'));
 }
 
 $a = $_POST['assignment'];
 
 if($_GET['action'] == 'add' && isset($a))
 {
+	foreach($a as $key => $val)
+		$a[$key] = trim($val);
+	
 	$period = sprintf('%d',$a['period']);
 
 	if($period < 0 || $period > 3)
 		$period = 1;
 
-	$a['at'] = trim($a['at']);
-
 	switch($period)
 	{
 		case 0:
@@ -66,7 +64,7 @@ if($_GET['action'] == 'add' && isset($a))
 			}
 			
 			if($at < 1 || $at > 7)
-				$error['at'] = 'Nieprawidowy dzie tygodnia (1-7)!';
+				$error['at'] = trans('Incorrect day of week (1-7)!');
 		break;
 
 		case 1:
@@ -78,13 +76,13 @@ if($_GET['action'] == 'add' && isset($a))
 			$a['at'] = $at;
 			
 			if($at > 28 || $at < 1)
-				$error['at'] = 'Nieprawidowy dzie miesica (1-28)!';
+				$error['at'] = trans('Incorrect day of month (1-28)!');
 		break;
 
 		case 2:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']) && $a['at'])
 			{
-				$error['at'] = 'Niepoprawny format daty (DD/MM)';
+				$error['at'] = trans('Incorrect date format! Enter date in DD/MM format!');
 			}
 			elseif($_CONFIG['phpui']['use_current_payday'] && !$a['at'])
 			{
@@ -94,15 +92,15 @@ if($_GET['action'] == 'add' && isset($a))
 			}
 			else
 			{
-				list($d,$m) = split('/',trim($a['at']));
+				list($d,$m) = split('/',$a['at']);
 			}
 			
 			if(!$error)
 			{
 				if($d>30 || $d<1 || ($d>28 && $m==2))
-					$error['at'] = 'Niepoprawna liczba dni w miesicu';
+					$error['at'] = trans('This month doesn\'t contain specified number of days');
 				if($m>3 || $m<1)
-					$error['at'] = 'Niepoprawny numer miesica (max.3)';
+					$error['at'] = trans('Incorrect month number (max.3)!');
 
 				$at = ($m-1) * 100 + $d;
 			}
@@ -111,7 +109,7 @@ if($_GET['action'] == 'add' && isset($a))
 		case 3:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',$a['at']) && $a['at'])
 			{
-				$error['at'] = 'Niepoprawny format daty (DD/MM)';
+				$error['at'] = trans('Incorrect date format! Enter date in DD/MM format!');
 			}
 			elseif($_CONFIG['phpui']['use_current_payday'] && !$a['at'])
 			{
@@ -121,15 +119,15 @@ if($_GET['action'] == 'add' && isset($a))
 			}
 			else
 			{
-				list($d,$m) = split('/',trim($a['at']));
+				list($d,$m) = split('/',$a['at']);
 			}
 			
 			if(!$error)
 			{
 				if($d>30 || $d<1 || ($d>28 && $m==2))
-					$error['at'] = 'Niepoprawna liczba dni w miesicu';
+					$error['at'] = trans('This month doesn\'t contain specified number of days');
 				if($m>12 || $m<1)
-					$error['at'] = 'Niepoprawny numer miesica';
+					$error['at'] = trans('Incorrect month number');
 			
 				$ttime = mktime(12, 0, 0, $m, $d, 1990);
 				$at = date('z',$ttime) + 1;
@@ -137,37 +135,43 @@ if($_GET['action'] == 'add' && isset($a))
 		break;
 	}
 
-	if(trim($a['datefrom']) == '')
+	if($a['datefrom'] == '')
 		$from = 0;
-	elseif(eregi('^[0-9]{4}/[0-9]{2}/[0-9]{2}$',trim($a['datefrom'])))
+	elseif(eregi('^[0-9]{4}/[0-9]{2}/[0-9]{2}$',$a['datefrom']))
 	{
-		list($y, $m, $d) = split('/', trim($a['datefrom']));
+		list($y, $m, $d) = split('/', $a['datefrom']);
 		if(checkdate($m, $d, $y))
 			$from = mktime(0, 0, 0, $m, $d, $y);
 		else
-			$error['datefrom'] = 'Pocztek okresu naliczania jest niepoprawny!';
+			$error['datefrom'] = trans('Incorrect charging start time!');
 	}
 	else
-		$error['datefrom'] = 'Pocztek okresu naliczania jest niepoprawny!';
+		$error['datefrom'] = trans('Incorrect charging start time!');
 
-	if(trim($a['dateto']) == '')
+	if($a['dateto'] == '')
 		$to = 0;
-	elseif(eregi('^[0-9]{4}/[0-9]{2}/[0-9]{2}$',trim($a['dateto'])))
+	elseif(eregi('^[0-9]{4}/[0-9]{2}/[0-9]{2}$',$a['dateto']))
 	{
-		list($y, $m, $d) = split('/', trim($a['dateto']));
+		list($y, $m, $d) = split('/', $a['dateto']);
 		if(checkdate($m, $d, $y))
 			$to = mktime(23, 59, 59, $m, $d, $y);
 		else
-			$error['dateto'] = 'Koniec okresu naliczania jest niepoprawny!';
+			$error['dateto'] = trans('Incorrect charging end time!');
 	}
 	else
-		$error['dateto'] = 'Koniec okresu naliczania jest niepoprawny!';
+		$error['dateto'] = trans('Incorrect charging end time!');
 
 	if($to < $from && $to != 0 && $from != 0)
-		$error['dateto'] = 'Zakres dat jest niepoprawny!';
+		$error['dateto'] = trans('Incorrect date range!');
 
 	if($a['tariffid']=='')
-		$error['tariffid'] = 'Nie wybrae taryfy!';
+		$error['tariffid'] = trans('Subscription not selected!');
+
+	$a['discount'] = str_replace(',','.',$a['discount']);
+	if($a['discount']=='')
+		$a['discount'] = 0;
+	elseif($a['discount']<0 || $a['discount']>99.99 || !is_numeric($a['discount']))
+		$error['discount'] = trans('Wrong discount value!');
 
 	if($a['tariffid']==0)
 	{
@@ -177,15 +181,14 @@ if($_GET['action'] == 'add' && isset($a))
 
 	if(!$error) 
 	{
-		$LMS->AddAssignment(array('tariffid' => $a['tariffid'], 'userid' => $_GET['id'], 'period' => $period, 'at' => $at, 'invoice' => sprintf('%d',$a['invoice']), 'datefrom' => $from, 'dateto' => $to ));
-		header('Location: ?m=userinfo&id='.$_GET['id']);
-		die;
+		$LMS->AddAssignment(array('tariffid' => $a['tariffid'], 'userid' => $_GET['id'], 'period' => $period, 'at' => $at, 'invoice' => sprintf('%d',$a['invoice']), 'datefrom' => $from, 'dateto' => $to, 'discount' => $a['discount'] ));
+		$SESSION->redirect('?'.$SESSION->get('backto'));
 	}
 }
 
 $userinfo = $LMS->GetUser($_GET['id']);
 
-$layout['pagetitle'] = 'Informacje o uytkowniku: '.$userinfo['username'];
+$layout['pagetitle'] = trans('Customer Information: $0',$userinfo['username']);
 
 $SMARTY->assign('usernodes',$LMS->GetUserNodes($userinfo['id']));
 $SMARTY->assign('balancelist',$LMS->GetUserBalanceList($userinfo['id']));
@@ -199,6 +202,6 @@ $SMARTY->assign('error', $error);
 $SMARTY->assign('assignment', $a);
 $SMARTY->display('userinfo.html');
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 ?>
