@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userbalance.php,v 1.26.2.2 2005/01/01 19:20:09 alec Exp $
+ *  $Id: userbalance.php,v 1.30.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 if(!$LMS->UserExists($_GET['id']))
 	header("Location: ?m=userlist");
@@ -32,7 +32,7 @@ if(!$LMS->UserExists($_GET['id']))
 $username=$LMS->GetUserName($_GET['id']);
 $id = $_GET['id'];
 
-$layout['pagetitle'] = 'Rachunek uytkownika: <A HREF="?m=userinfo&id='.$_GET['id'].'">'.$username.'</A>';
+$layout['pagetitle'] = trans('Customer Balance: <A HREF="?m=userinfo&id=$0">$1</A>', $_GET['id'], $username);
 
 $SMARTY->assign('balancelist',$LMS->GetUserBalanceList($_GET['id']));
 $SMARTY->assign('username',$username);
