@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,27 +21,27 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userdel.php,v 1.26.2.2 2005/01/01 19:20:09 alec Exp $
+ *  $Id: userdel.php,v 1.31.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
-$layout['pagetitle'] = "Usunicie uytkownika ID: ".sprintf("%04d",$_GET['id']);
+$layout['pagetitle'] = trans('Customer Remove: $0',sprintf("%04d",$_GET['id']));
 $SMARTY->assign('userid',$_GET['id']);
 
 if (!$LMS->UserExists($_GET['id']))
 {
-	$body = "<H1>".$layout['pagetitle']."</H1><P>Podany przez Ciebie ID jest bdny bd nie istnieje w bazie danych.</P>";
+	$body = '<H1>'.$layout['pagetitle'].'</H1><P>'.trans('Incorrect Customer ID.').'</P>';
 }else{
 
 	if($_GET['is_sure']!=1)
 	{
-		$body = "<H1>".$layout['pagetitle']."</H1>";
-		$body .= "<P>Czy jeste pewien e chcesz usun uytkownika ".$LMS->GetUserName($_GET['id'])."?</P>"; 
-		$body .= "<P>Wszystkie dane uytkownika zostan utracone, a take wszystkie przypisane temu uytkownikowi komputery zostan usunite.</P>";
-		$body .= "<P><A HREF=\"?m=userdel&id=".$_GET['id']."&is_sure=1\">Tak, jestem pewien.</A></P>";
+		$body = '<H1>'.$layout['pagetitle'].'</H1>';
+		$body .= '<P>'.trans('Do you want to remove $0 customer?',$LMS->GetUserName($_GET['id'])).'</P>'; 
+		$body .= '<P>'.trans('All user data and computers bound to this customer will be lost!').'</P>';
+		$body .= '<P><A HREF="?m=userdel&id='.$_GET['id'].'&is_sure=1">'.trans('Yes, I do.').'</A></P>';
 	}else{
-		header("Location: ?".$_SESSION['backto']);
-		$body = "<H1>".$layout['pagetitle']."</H1>";
-		$body .= "<P>Uytkownik ".$LMS->GetUserName($_GET['id'])." zosta usunity.</P>";
+		header("Location: ?".$SESSION->get('backto'));
+		$body = '<H1>'.$layout['pagetitle'].'</H1>';
+		$body .= '<P>'.trans('Customer $0 has been removed.',$LMS->GetUserName($_GET['id'])).'</P>';
 		$LMS->DeleteUser($_GET['id']);
 	}
 		
