@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,56 +21,53 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: useredit.php,v 1.66.2.4 2005/01/01 19:20:10 alec Exp $
+ *  $Id: useredit.php,v 1.83.2.2 2005/05/20 11:44:43 kondi Exp $
  */
 
-$userdata = $_POST['userdata'];
+$action = isset($_GET['action']) ? $_GET['action'] : '';
 
-if($LMS->UserExists($_GET['id']) < 0 && $_GET['action'] != 'recover')
+if($LMS->UserExists($_GET['id']) < 0 && $action != 'recover')
 {
-	header('Location: ?m=userinfo&id='.$_GET['id']);
-	die;
+	$SESSION->redirect('?m=userinfo&id='.$_GET['id']);
 }
 elseif(! $LMS->UserExists($_GET['id']))
 {
-	header('Location: ?m=userlist');
-	die;
+	$SESSION->redirect('?m=userlist');
 }
-elseif($_GET['action'] == 'usergroupdelete')
+elseif($action == 'usergroupdelete')
 {
 	$LMS->UserassignmentDelete(array('userid' => $_GET['id'], 'usergroupid' => $_GET['usergroupid']));
-	header('Location: ?m=userinfo&id='.$_GET['id']);
-	die;
+	$SESSION->redirect('?m=userinfo&id='.$_GET['id']);
 }
-elseif($_GET['action'] == 'usergroupadd')
+elseif($action == 'usergroupadd')
 {
 	if ($LMS->UsergroupExists($_POST['usergroupid']))
 		$LMS->UserassignmentAdd(array('userid' => $_GET['id'], 'usergroupid' => $_POST['usergroupid']));
-	header('Location: ?m=userinfo&id='.$_GET['id']);
-	die;
+	$SESSION->redirect('?m=userinfo&id='.$_GET['id']);
 }
-elseif(isset($userdata))
+elseif(isset($_POST['userdata']))
 {
+	$userdata = $_POST['userdata'];
 	foreach($userdata as $key=>$value)
 		$userdata[$key] = trim($value);
 
 	if($userdata['lastname']=='')
-		$error['username'] = 'Pola \'nazwisko/nazwa\' oraz imi nie mog by puste!';
+		$error['username'] = trans('\'Last/Company Name\' and \'First Name\' fields cannot be empty!');
 	
 	if($userdata['address']=='')
-		$error['address'] = 'Prosz poda adres!';
+		$error['address'] = trans('Address required!');
 
-	if($userdata['nip'] !='' && !check_nip($userdata['nip']))
-		$error['nip'] = 'Podany NIP jest bdny!';
+	if($userdata['nip'] !='' && !check_ten($userdata['nip']))
+		$error['nip'] = trans('Incorrect Tax Exempt Number!');
 
-	if(!check_pesel($userdata['pesel']) && $userdata['pesel'] != '')
-		$error['pesel'] = 'Podany PESEL jest bdny!';
+	if(!check_ssn($userdata['pesel']) && $userdata['pesel'] != '')
+		$error['pesel'] = trans('Incorrect Social Security Number!');
 
-	if($userdata['zip'] !='' && !eregi('^[0-9]{2}-[0-9]{3}$',$userdata['zip']))
-		$error['zip'] = 'Podany kod pocztowy jest bdny!';
+	if($userdata['zip'] !='' && !check_zip($userdata['zip']))
+		$error['zip'] = trans('Incorrect ZIP code!');
 
 	if($userdata['email']!='' && !check_email($userdata['email']))
-		$error['email'] = 'Podany email nie wydaje si by poprawny!';
+		$error['email'] = trans('Incorrect email!');
 
 	if($userdata['gguin'] == '')
 		$userdata['gguin'] = 0;
@@ -79,19 +76,21 @@ elseif(isset($userdata))
 		$userdata['pin'] = 0;
 
 	if($userdata['gguin']!=0 && !eregi('^[0-9]{4,}$',$userdata['gguin']))
-		$error['gguin'] = 'Podany numer GG jest niepoprawny!';
+		$error['gguin'] = trans('Incorrect IM uin!');
 
 	if($userdata['pin']!=0 && !eregi('^[0-9]{4,6}$',$userdata['pin']))
-		$error['pin'] = 'Podany numer PIN jest niepoprawny!';
+		$error['pin'] = trans('Incorrect PIN code!');
 
 	if($userdata['status']!=3&&$LMS->GetUserNodesNo($userdata['id'])) 
-		$error['status'] = 'Tylko podczony uytkownik moe posiada komputery!';
+		$error['status'] = trans('Only customer with \'connected\' status can own computers!');
 		
-	if (!isset($error)){
+	if (!$error)
+	{
 		$LMS->UserUpdate($userdata);
-		header('Location: ?m=userinfo&id='.$userdata['id']);
-		die;
-	}else{
+		$SESSION->redirect('?m=userinfo&id='.$userdata['id']);
+	}
+	else
+	{
 		$olddata=$LMS->GetUser($_GET['id']);
 		$userinfo=$userdata;
 		$userinfo['createdby']=$olddata['createdby'];
@@ -111,7 +110,7 @@ elseif(isset($userdata))
 		$userinfo['shownodes'] = TRUE;
 }
 
-$layout['pagetitle'] = 'Edycja danych uytkownika: '.$userinfo['username'];
+$layout['pagetitle'] = trans('Customer Edit: $0',$userinfo['username']);
 
 $SMARTY->assign('usernodes',$LMS->GetUserNodes($userinfo['id']));
 $SMARTY->assign('balancelist',$LMS->GetUserBalanceList($userinfo['id']));
@@ -120,9 +119,9 @@ $SMARTY->assign('assignments',$LMS->GetUserAssignments($_GET['id']));
 $SMARTY->assign('usergroups',$LMS->UsergroupGetForUser($_GET['id']));
 $SMARTY->assign('otherusergroups',$LMS->GetGroupNamesWithoutUser($_GET['id']));
 $SMARTY->assign('userinfo',$userinfo);
-$SMARTY->assign('recover',($_GET['action'] == 'recover' ? 1 : 0));
+$SMARTY->assign('recover',($action == 'recover' ? 1 : 0));
 $SMARTY->display('useredit.html');
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 ?>
