@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,42 +21,41 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: usergroupadd.php,v 1.5.2.2 2005/01/01 19:20:12 alec Exp $
+ *  $Id: usergroupadd.php,v 1.10.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
-$usergroupadd = $_POST['usergroupadd'];
-
-if(isset($usergroupadd))
+if(isset($_POST['usergroupadd']))
 {
+	$usergroupadd = $_POST['usergroupadd'];
+	
 	foreach($usergroupadd as $key => $value)
 		$usergroupadd[$key] = trim($value);
 
 	if($usergroupadd['name']=='' && $usergroupadd['description']=='')
 	{
-		header("Location: ?m=usergrouplist");
-		die;
+		$SESSION->redirect('?m=usergrouplist');
 	}
 	
 	if($usergroupadd['name'] == '')
-		$error['name'] = 'Musisz poda nazw grupy!';
+		$error['name'] = trans('Group name required!');
 	elseif(strlen($usergroupadd['name']) > 16)
-		$error['name'] = 'Podana nazwa jest za duga!';
+		$error['name'] = trans('Group name is too long!');
 	elseif($LMS->UsergroupGetId($usergroupadd['name']))
-		$error['name'] = 'Istnieje ju grupa o nazwie '.$usergroupadd['name'];
+		$error['name'] = trans('Group with name $0 already exists!',$usergroupadd['name']);
 	elseif(!eregi("^[._a-z0-9-]+$",$usergroupadd['name']))
-		$error['name'] = 'Podana nazwa zawiera niepoprawne znaki!';
+		$error['name'] = trans('Invalid chars in group name!');
 
-	if(!$error){
-		header('Location: ?m=usergrouplist&id='.$LMS->UsergroupAdd($usergroupadd));
-		die;
+	if(!$error)
+	{
+		$SESSION->redirect('?m=usergrouplist&id='.$LMS->UsergroupAdd($usergroupadd));
 	}
 	
+	$SMARTY->assign('error',$error);
+	$SMARTY->assign('usergroupadd',$usergroupadd);
 }
 
-$layout['pagetitle'] = 'Nowa grupa';
+$layout['pagetitle'] = trans('New Group');
 
-$SMARTY->assign('error',$error);
-$SMARTY->assign('usergroupadd',$usergroupadd);
 $SMARTY->display('usergroupadd.html');
 
 ?>
