@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,81 +21,77 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: usergroupedit.php,v 1.7.2.3 2005/01/01 19:20:12 alec Exp $
+ *  $Id: usergroupedit.php,v 1.15.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
-$userassignments = $_POST['userassignments'];
-$oper = $_POST['oper'];
-
-if(isset($userassignments))
+if(!$LMS->UsergroupExists($_GET['id']))
 {
-	if (sizeof($userassignments['gmuserid']) && $oper=='0')
+	$SESSION->redirect('?m=usergrouplist');
+}
+
+if(isset($_POST['userassignments']))
+{
+	$oper = $_POST['oper'];
+	$userassignments = $_POST['userassignments'];
+	
+	if(isset($userassignments['gmuserid']) && $oper=='0')
 	{
-		$assignment['usergroupid'] = $userassignments['backid'];
+		$assignment['usergroupid'] = $_GET['id'];
 		foreach($userassignments['gmuserid'] as $value)
 		{
 			$assignment['userid'] = $value;
 			$LMS->UserassignmentDelete($assignment);
 		}
-		header('Location: ?'.$_SESSION['backto']);
-		die;
+		$SESSION->redirect('?'.$SESSION->get('backto'));
 	}
 
-	if (sizeof($userassignments['muserid']) && $oper=='1')
+	if (isset($userassignments['muserid']) && $oper=='1')
 	{
-		$assignment['usergroupid'] = $userassignments['backid'];
+		$assignment['usergroupid'] = $_GET['id'];
 		foreach($userassignments['muserid'] as $value)
 		{
 			$assignment['userid'] = $value;
 			if(! $LMS->UserassignmentExist($assignment['usergroupid'],$value))
 				$LMS->UserassignmentAdd($assignment);
 		}
-		header('Location: ?'.$_SESSION['backto']);
-		die;
+		$SESSION->redirect('?'.$SESSION->get('backto'));
 	}
 }
 
-if(!$LMS->UsergroupExists($_GET['id']))
-{
-	header('Location: ?m=usergrouplist');
-	die;
-}
-
 $usergroup = $LMS->UsergroupGet($_GET['id']);
-$users = $LMS->GetUserWithoutGroupNames($usergroup['id']);
+$users = $LMS->GetUserWithoutGroupNames($_GET['id']);
 
-$layout['pagetitle'] = 'Edycja grupy: '.$usergroup['name'];	
+$layout['pagetitle'] = trans('Group Edit: $0', $usergroup['name']);
 
-$usergroupedit = $_POST['usergroup'];
-
-if(isset($usergroupedit))
+if(isset($_POST['usergroup']))
 {
+	$usergroupedit = $_POST['usergroup'];
+
 	foreach($usergroupedit as $key => $value)
 		$usergroupedit[$key] = trim($value);
 
 	$usergroupedit['id'] = $_GET['id'];
 	
 	if($usergroupedit['name'] == '')
-		$error['name'] = 'Musisz poda nazw grupy!';
+		$error['name'] = trans('Group name required!');
 	elseif(strlen($usergroupedit['name']) > 16)
-		$error['name'] = 'Podana nazwa jest za duga!';
+		$error['name'] = trans('Group name is too long!');
 	elseif( ($id = $LMS->UsergroupGetId($usergroupedit['name'])) && $id != $usergroupedit['id'])
-		$error['name'] = 'Istnieje ju grupa o nazwie '.$usergroupedit['name'];
+		$error['name'] = trans('Group with name $0 already exists!',$usergroupedit['name']);
 	elseif(!eregi("^[._a-z0-9-]+$",$usergroupedit['name']))
-		$error['name'] = 'Podana nazwa zawiera niepoprawne znaki!';
+		$error['name'] = trans('Invalid chars in group name!');
 
 	if(!$error)
 	{
 		$LMS->UsergroupUpdate($usergroupedit);
-		header('Location: ?m=usergroupinfo&id='.$usergroup['id']);
-		die;
+		$SESSION->redirect('?m=usergroupinfo&id='.$usergroup['id']);
 	}
 
 	$usergroup['description'] = $usergroupedit['description'];
 	$usergroup['name'] = $usergroupedit['name'];
 }
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('usergroup',$usergroup);
 $SMARTY->assign('error', $error);
