@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,15 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: usergroupinfo.php,v 1.8.2.3 2005/01/01 19:20:13 alec Exp $
+ *  $Id: usergroupinfo.php,v 1.15.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
 if ($id = $_GET['id'])
 {
 	if (!$LMS->UsergroupExists($id))
 	{
-		header('Location: ?m=usergrouplist');
-		die;
+		$SESSION->redirect('?m=usergrouplist');
 	}
 }
 
@@ -37,9 +36,9 @@ $usergroup = $LMS->UsergroupGet($_GET['id']);
 $users = $LMS->GetUserWithoutGroupNames($_GET['id']);
 $userscount = sizeof($users);
 
-$layout['pagetitle'] = 'Informacja o grupie: '.$usergroup['name'];
+$layout['pagetitle'] = trans('Group Info: $0',$usergroup['name']);
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('usergroup',$usergroup);
 $SMARTY->assign('users', $users);
