@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: usergrouplist.php,v 1.2.2.2 2005/01/01 19:20:13 alec Exp $
+ *  $Id: usergrouplist.php,v 1.5.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
-$layout['pagetitle'] = "Lista grup";
+$layout['pagetitle'] = trans('Group List');
 
 $usergrouplist = $LMS->UsergroupGetList();
 
