@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,16 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: usergroupmove.php,v 1.1.2.2 2005/01/01 19:20:13 alec Exp $
+ *  $Id: usergroupmove.php,v 1.5.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
 if($LMS->UsergroupExists($_GET['from']) && $LMS->UsergroupExists($_GET['to']) && $_GET['is_sure'] = 1)
 {
 	$LMS->UsergroupMove($_GET['from'],$_GET['to']);
-	header("Location: ?m=usergroupinfo&id=".$_GET['to']);
-	die;
+	$SESSION->redirect('?m=usergroupinfo&id='.$_GET['to']);
 }
 else
-	header("Location: ?".$_SESSION['backto']);
+	header('Location: ?'.$SESSION->get('backto'));
 
-?>
\ No newline at end of file
+?>
