@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,19 +21,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userinfo.php,v 1.36.2.2 2005/01/01 19:20:14 alec Exp $
+ *  $Id: userinfo.php,v 1.44.2.1 2005/05/13 20:10:07 alec Exp $
  */
 
 if(!eregi("^[0-9]+$",$_GET['id']))
 {
-	header('Location: ?m=userlist');
-	die;
+	$SESSION->redirect('?m=userlist');
 }
 
 if($LMS->UserExists($_GET['id']) == 0)
 {
-	header('Location: ?m=userlist');
-	die;
+	$SESSION->redirect('?m=userlist');
 }
 
 $userinfo = $LMS->GetUser($_GET['id']);
@@ -43,10 +41,11 @@ $otherusergroups = $LMS->GetGroupNamesWithoutUser($_GET['id']);
 $balancelist = $LMS->GetUserBalanceList($_GET['id']);
 $usernodes = $LMS->GetUserNodes($_GET['id']);
 $tariffs = $LMS->GetTariffs();
+$contractlist = $LMS->GetContractList();
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
-$layout['pagetitle'] = 'Informacje o uytkowniku: '.$userinfo['username'];
+$layout['pagetitle'] = trans('Customer Info: $0',$userinfo['username']);
 
 $usernodes['ownerid'] = $_GET['id'];
 $SMARTY->assign(
@@ -56,9 +55,10 @@ $SMARTY->assign(
 			'assignments' => $assigments,
 			'usergroups' => $usergroups,
 			'otherusergroups' => $otherusergroups,
-			'error' => $error,
 			'userinfo' => $userinfo,
-			'tariffs' => $tariffs
+			'tariffs' => $tariffs,
+			'contractlist' => $contractlist,
+			'contractcount' => sizeof($contractlist)
 		     )
 		);
 $SMARTY->display('userinfo.html');
