@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,38 +21,41 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userwarn.php,v 1.1.2.2 2005/01/01 19:20:15 alec Exp $
+ *  $Id: userwarn.php,v 1.8.2.1 2005/05/13 20:10:08 alec Exp $
  */
 
-$setwarnings = $_POST['setwarnings'];
+$setwarnings = isset($_POST['setwarnings']) ? $_POST['setwarnings'] : array();
 
-if(sizeof($setwarnings['muserid']))
+if(isset($setwarnings['muserid']))
 {
+	$warnon = isset($setwarnings['warnon']) ? $setwarnings['warnon'] : FALSE;
+	$warnoff = isset($setwarnings['warnoff']) ? $setwarnings['warnoff'] : FALSE;
+	$message = isset($setwarnings['message']) ? $setwarnings['message'] : '';
+	
 	foreach($setwarnings['muserid'] as $uid)
 	{
-		if($setwarnings['warnon'])
+		if($warnon)
 			$LMS->NodeSetWarnU($uid, TRUE);
-		if($setwarnings['warnoff']) 
+		if($warnoff) 
 			$LMS->NodeSetWarnU($uid, FALSE);
 		
-		if (isset($setwarnings['message']))
+		if($message)
 		{
 			$LMS->SetTS('users');
-			$LMS->DB->Execute('UPDATE users SET message=? WHERE id=?', array($setwarnings['message'],$uid));
+			$LMS->DB->Execute('UPDATE users SET message=? WHERE id=?', array($message, $uid));
 		}
 	}
 
-	$_SESSION['warnmessage'] = $setwarnings['message'];
-	$_SESSION['warnon'] = $setwarnings['warnon'];
-	$_SESSION['warnoff'] = $setwarnings['warnoff'];
+	$SESSION->save('warnmessage', $message);
+	$SESSION->save('warnon', $warnon);
+	$SESSION->save('warnoff', $warnoff);
 	
-	header('Location: ?'.$_SESSION['backto']);
-	die;
+	$SESSION->redirect('?'.$SESSION->get('backto'));
 }
 
-$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+$SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
-$layout['pagetitle'] = 'Ostrzeenia';
+$layout['pagetitle'] = trans('Warnings');
 
 $userlist = $LMS->DB->GetAll(
 		    'SELECT users.id AS id, MAX(warning) AS warning, '.
@@ -60,9 +63,9 @@ $userlist = $LMS->DB->GetAll(
 		    FROM users LEFT JOIN nodes ON users.id = ownerid WHERE deleted = 0 
 		    GROUP BY users.id, lastname, users.name ORDER BY username ASC');
 
-$SMARTY->assign('warnmessage', $_SESSION['warnmessage']);
-$SMARTY->assign('warnon', $_SESSION['warnon']);
-$SMARTY->assign('warnoff', $_SESSION['warnoff']);
+$SMARTY->assign('warnmessage', $SESSION->get('warnmessage'));
+$SMARTY->assign('warnon', $SESSION->get('warnon'));
+$SMARTY->assign('warnoff', $SESSION->get('warnoff'));
 $SMARTY->assign('userlist',$userlist);
 $SMARTY->display('userwarnings.html');
 
