@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.4.5 Persus
+ * LMS version 1.6.1 Ishta
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,11 +21,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: welcome.php,v 1.37.2.3 2005/01/01 19:20:15 alec Exp $
+ *  $Id: welcome.php,v 1.43.2.1 2005/05/13 20:10:08 alec Exp $
  */
 
 require_once($_LIB_DIR.'/Sysinfo.class.php');
-require_once($_LIB_DIR.'/fortunes.php');
+@include($_LIB_DIR.'/locale/'.$_language.'/fortunes.php');
 
 $SI = new Sysinfo;
 
@@ -34,6 +34,8 @@ $layout['pagetitle'] = 'LAN Management System';
 $layout['dbversion'] = $LMS->DB->GetDBVersion();
 $layout['dbtype'] = $LMS->CONFIG['database']['type'];
 
+$SMARTY->assign('updates', $LMS->CheckUpdates());
+$SMARTY->assign('regdata', $LMS->GetRegisterData());
 $SMARTY->assign('rtstats', $LMS->RTStats());
 $SMARTY->assign('sysinfo',$SI->get_sysinfo());
 $SMARTY->assign('userstats',$LMS->UserStats());
